@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2013, OFFIS e.V.
+ *  Copyright (C) 2003-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -299,7 +299,7 @@ static OFCondition putElementContent(xmlNodePtr current,
                 OFLOG_ERROR(xml2dcmLogger, "filename for element " << element->getTag() << " is missing, empty element inserted");
         } else {
             OFString dicomVal;
-            /* convert character set from UTF8 (for specific VRs only) */
+            /* convert character set from UTF-8 (for specific VRs only) */
             if (((dcmEVR == EVR_PN) || (dcmEVR == EVR_SH) || (dcmEVR == EVR_LO) ||
                  (dcmEVR == EVR_ST) || (dcmEVR == EVR_LT) || (dcmEVR == EVR_UT)) &&
                 (xmlStrlen(elemVal) > 0) && convertUtf8ToCharset(elemVal, dicomVal))
@@ -825,19 +825,9 @@ int main(int argc, char *argv[])
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--enable-new-vr"))
-        {
-            dcmEnableUnknownVRGeneration.set(OFTrue);
-            dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-            dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
-            dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
-        }
+            dcmEnableGenerationOfNewVRs();
         if (cmd.findOption("--disable-new-vr"))
-        {
-            dcmEnableUnknownVRGeneration.set(OFFalse);
-            dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-            dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
-            dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
-        }
+            dcmDisableGenerationOfNewVRs();
         cmd.endOptionBlock();
 
         cmd.beginOptionBlock();
