@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2011, OFFIS e.V.
+ *  Copyright (C) 1994-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -64,6 +64,26 @@ class DCMTK_DCMDATA_EXPORT DcmElement
      */
     DcmElement &operator=(const DcmElement &obj);
 
+    /** comparison operator that compares the normalized value of this element
+     *  with a given element of the same type (e.g. an DcmUnsignedShort with a
+     *  DcmUnsignedShort). The tag of the element is also considered as the first
+     *  component that is compared, followed by the object types (VR, i.e. DCMTK'S EVR).
+     *  DcmElement's default implementation does only compare the tag and EVR while
+     *  the derived classes implement the value comparisons by comparing all the
+     *  components that make up the value, preferrably in the order declared in
+     *  the object (if applicable).
+     *  @param  rhs the right hand side of the comparison
+     *  @return 0 if the object values are equal.
+     *          -1 if either the value of the first component that does not match
+     *          is lower in this object than in rhs, or all compared components match
+     *          but this object has fewer components than rhs. Also returned if rhs
+     *          cannot be casted to this object type.
+     *          1 if either the value of the first component that does not match
+     *          is greater in this object than in rhs object, or all compared
+     *          components match but the this component is longer.
+     */
+    virtual int compare(const DcmElement& rhs) const =0;
+
     /** Virtual object copying. This method can be used for DcmObject
      *  and derived classes to get a deep copy of an object. Internally
      *  the assignment operator is called if the given DcmObject parameter
