@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2015, OFFIS e.V.
+ *  Copyright (C) 1994-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -66,10 +66,6 @@ const unsigned short OFM_dcmstscp = 25;
 const unsigned short OFM_dcmqrdbx = 26;
 const unsigned short OFM_dcmkosel = 27;
 const unsigned short OFM_dcmenc   = 28;
-const unsigned short OFM_dcmiod   = 29;
-const unsigned short OFM_dcmseg   = 30;
-const unsigned short OFM_dcmfg    = 31;
-
 
 // condition constants
 
@@ -78,31 +74,31 @@ const unsigned short OFM_dcmfg    = 31;
  *  defined in module ofstd.
  */
 //@{
-/// Invalid tag
+/// invalid tag
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidTag;
-/// Tag not found
+/// tag not found
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_TagNotFound;
-/// Invalid VR
+/// invalid VR
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidVR;
-/// Invalid stream
+/// invalid stream
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidStream;
-/// End of stream
+/// end of stream
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_EndOfStream;
-/// Corrupted data
+/// corrupted data
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CorruptedData;
-/// Illegal call, perhaps wrong parameters
+/// illegal call, perhaps wrong parameters
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_IllegalCall;
-/// Sequence end
+/// sequence end
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_SequEnd;
-/// Doubled tag
+/// doubled tag
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_DoubledTag;
 /// I/O suspension or premature end of stream
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_StreamNotifyClient;
-/// Stream mode (R/W, random/sequence) is wrong
+/// stream mode (R/W, random/sequence) is wrong
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_WrongStreamMode;
-/// Item end
+/// item end
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_ItemEnd;
-/// Compressed/uncompressed pixel representation not found
+/// compressed/uncompressed pixel representation not found
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_RepresentationNotFound;
 /// Pixel representation cannot be changed to requested transfer syntax
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotChangeRepresentation;
@@ -142,22 +138,6 @@ extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_ItemDelimitationItemMissin
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_PrematureSequDelimitationItem;
 /// Invalid DICOMDIR, e.g. corrupted data structures
 extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidDICOMDIR;
-/// Unknown VR, e.g. tag not found in data dictionary
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnknownVR;
-/// Invalid value, e.g. element value has been provided that does not match the VR
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InvalidValue;
-/// An expected Item was not found
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_ItemNotFound;
-/// Given transfersyntax is unknown
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_UnknownTransferSyntax;
-/// Cannot check
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_CannotCheck;
-/// Missing value, e.g. element must contain a value but is empty
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_MissingValue;
-/// Missing attribute
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_MissingAttribute;
-/// Internal error
-extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InternalError;
 //@}
 
 // status code constants
@@ -166,8 +146,9 @@ extern DCMTK_DCMDATA_EXPORT const OFConditionConst EC_InternalError;
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotSelectCharacterSet;
 /// error, cannot convert specific character set
 extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotConvertCharacterSet;
+
 /// error, cannot convert to XML
-extern DCMTK_DCMDATA_EXPORT const unsigned short EC_CODE_CannotConvertToXML;
+extern const unsigned short EC_CODE_CannotConvertToXML;
 
 
 #endif /* !DCERROR_H */
