@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2016, OFFIS e.V.
+ *  Copyright (C) 1994-2013, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -47,7 +47,7 @@
 
 
 DcmDataset::DcmDataset()
-  : DcmItem(DCM_ItemTag, DCM_UndefinedLength),
+  : DcmItem(ItemTag, DCM_UndefinedLength),
     OriginalXfer(EXS_Unknown),
     // the default transfer syntax is explicit VR with local endianness
     CurrentXfer((gLocalByteOrder == EBO_BigEndian) ? EXS_BigEndianExplicit : EXS_LittleEndianExplicit)
@@ -291,7 +291,6 @@ void DcmDataset::print(STD_NAMESPACE ostream&out,
 OFCondition DcmDataset::writeXML(STD_NAMESPACE ostream &out,
                                  const size_t flags)
 {
-    OFCondition l_error = EC_Normal;
     /* the Native DICOM Model as defined for Application Hosting needs special handling */
     if (flags & DCMTypes::XF_useNativeModel)
     {
@@ -319,20 +318,18 @@ OFCondition DcmDataset::writeXML(STD_NAMESPACE ostream &out,
         elementList->seek(ELP_first);
         do {
             dO = elementList->get();
-            l_error = dO->writeXML(out, flags & ~DCMTypes::XF_useXMLNamespace);
-        } while (l_error.good() && elementList->seek(ELP_next));
+            dO->writeXML(out, flags & ~DCMTypes::XF_useXMLNamespace);
+        } while (elementList->seek(ELP_next));
     }
-    if (l_error.good())
+    /* write XML end tag (depending on output format) */
+    if (flags & DCMTypes::XF_useNativeModel)
     {
-        /* write XML end tag (depending on output format) */
-        if (flags & DCMTypes::XF_useNativeModel)
-        {
-            out << "</NativeDicomModel>" << OFendl;
-        } else {
-            out << "</data-set>" << OFendl;
-        }
+        out << "</NativeDicomModel>" << OFendl;
+    } else {
+        out << "</data-set>" << OFendl;
     }
-    return l_error;
+    /* always report success */
+    return EC_Normal;
 }
 
 
@@ -369,25 +366,25 @@ OFCondition DcmDataset::read(DcmInputStream &inStream,
                     case EXS_LittleEndianExplicit:
                     case EXS_BigEndianExplicit:
                     case EXS_BigEndianImplicit:
-                        DCMDATA_DEBUG("DcmDataset::read() trying to detect transfer syntax of uncompressed data set");
+                        DCMDATA_DEBUG("DcmDataset::read() trying to detect transfer syntax of uncompressed dataset");
                         OriginalXfer = checkTransferSyntax(inStream);
                         if ((xfer != EXS_Unknown) && (OriginalXfer != xfer))
-                            DCMDATA_WARN("DcmDataset: Wrong transfer syntax specified, detecting from data set");
+                            DCMDATA_WARN("DcmDataset: Wrong transfer syntax specified, detecting from dataset");
                         break;
                     default:
-                        DCMDATA_DEBUG("DcmDataset::read() data set seems to be compressed, so transfer syntax is not detected");
+                        DCMDATA_DEBUG("DcmDataset::read() dataset seems to be compressed, so transfer syntax is not detected");
                         OriginalXfer = xfer;
                         break;
                 }
             }
-            else /* default behavior */
+            else /* default behaviour */
             {
                 /* If the transfer syntax which was passed equals EXS_Unknown we want to */
                 /* determine the transfer syntax from the information in the stream itself. */
                 /* If the transfer syntax is given, we want to use it. */
                 if (xfer == EXS_Unknown)
                 {
-                    DCMDATA_DEBUG("DcmDataset::read() trying to detect transfer syntax of data set (because it is unknown)");
+                    DCMDATA_DEBUG("DcmDataset::read() trying to detect transfer syntax of dataset (because it is unknown)");
                     OriginalXfer = checkTransferSyntax(inStream);
                 } else
                     OriginalXfer = xfer;
@@ -478,7 +475,7 @@ OFCondition DcmDataset::write(DcmOutputStream &outStream,
     if (errorFlag.good() && getTransferState() != ERW_ready)
     {
       /* Determine the transfer syntax which shall be used. Either we use the one which was passed, */
-      /* or (if it's an unknown transfer syntax) we use the one which is contained in OriginalXfer. */
+      /* or (if it's an unknown tranfer syntax) we use the one which is contained in OriginalXfer. */
       E_TransferSyntax newXfer = oxfer;
       if (newXfer == EXS_Unknown)
         newXfer = OriginalXfer;
@@ -685,11 +682,9 @@ OFCondition DcmDataset::chooseRepresentation(const E_TransferSyntax repType,
             if (!pixelData->canChooseRepresentation(repType, repParam))
                 l_error = EC_CannotChangeRepresentation;
             pixelStack.push(resultStack);
-        } else {
-            /* something is fishy with the pixel data element (wrong class) */
-            DCMDATA_ERROR("DcmDataset: Wrong class for pixel data element, cannot change representation");
-            l_error = EC_CannotChangeRepresentation;
         }
+        else
+            l_error = EC_CannotChangeRepresentation;
     }
     // then call the method doing the real work for all these elements
     while (l_error.good() && (pixelStack.size() > 0))
@@ -707,7 +702,7 @@ OFCondition DcmDataset::chooseRepresentation(const E_TransferSyntax repType,
 
         pixelStack.pop();
     }
-    // store current transfer syntax (if conversion was successfully)
+    // store current transfer syntax (if conversion was successfuly)
     if (l_error.good())
         CurrentXfer = repType;
     return l_error;
