@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2013, OFFIS e.V.
+ *  Copyright (C) 1994-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -82,7 +82,15 @@ DcmElement::DcmElement(const DcmElement &elem)
             // back to the caller.
             fValue = new (std::nothrow) Uint8[getLengthField() + 1 + pad];    // protocol error: odd value length
 #else
-            fValue = new Uint8[getLengthField() + 1 + pad];    // protocol error: odd value length
+            /* make sure that the pointer is set to NULL in case of error */
+            try
+            {
+                fValue = new Uint8[getLengthField() + 1 + pad];    // protocol error: odd value length
+            }
+            catch (STD_NAMESPACE bad_alloc const &)
+            {
+                fValue = NULL;
+            }
 #endif
             if (fValue)
                 fValue[getLengthField()] = 0;
@@ -96,7 +104,15 @@ DcmElement::DcmElement(const DcmElement &elem)
             // back to the caller.
             fValue = new (std::nothrow) Uint8[getLengthField() + pad];
 #else
-            fValue = new Uint8[getLengthField() + pad];
+            /* make sure that the pointer is set to NULL in case of error */
+            try
+            {
+                fValue = new Uint8[getLengthField() + pad];
+            }
+            catch (STD_NAMESPACE bad_alloc const &)
+            {
+                fValue = NULL;
+            }
 #endif
         }
 
@@ -151,7 +167,15 @@ DcmElement &DcmElement::operator=(const DcmElement &obj)
             // back to the caller.
             fValue = new (std::nothrow) Uint8[getLengthField() + 1 + pad];    // protocol error: odd value length
 #else
-            fValue = new Uint8[getLengthField() + 1 + pad];    // protocol error: odd value length
+            /* make sure that the pointer is set to NULL in case of error */
+            try
+            {
+                fValue = new Uint8[getLengthField() + 1 + pad];    // protocol error: odd value length
+            }
+            catch (STD_NAMESPACE bad_alloc const &)
+            {
+                fValue = NULL;
+            }
 #endif
             if (fValue)
                 fValue[getLengthField()] = 0;
@@ -165,7 +189,15 @@ DcmElement &DcmElement::operator=(const DcmElement &obj)
             // back to the caller.
             fValue = new (std::nothrow) Uint8[getLengthField() + pad];
 #else
-            fValue = new Uint8[getLengthField() + pad];
+            /* make sure that the pointer is set to NULL in case of error */
+            try
+            {
+                fValue = new Uint8[getLengthField() + pad];
+            }
+            catch (STD_NAMESPACE bad_alloc const &)
+            {
+                fValue = NULL;
+            }
 #endif
         }
 
@@ -186,14 +218,41 @@ DcmElement &DcmElement::operator=(const DcmElement &obj)
 }
 
 
+int DcmElement::compare(const DcmElement& rhs) const
+{
+    if (this == &rhs)
+        return 0;
+
+    DcmElement* myThis = OFconst_cast(DcmElement*, this);
+    DcmElement* myRhs = OFconst_cast(DcmElement*, &rhs);
+
+    DcmTagKey thisKey = (*myThis).getTag().getXTag();
+    DcmTagKey rhsKey = (*myRhs).getTag().getXTag();
+
+    if ( thisKey > rhsKey )
+    {
+        return 1;
+    }
+    else if (thisKey < rhsKey)
+    {
+        return -1;
+    }
+
+    if ( this->ident() != rhs.ident() )
+        return -1;
+
+    return 0;
+}
+
+
 OFCondition DcmElement::copyFrom(const DcmObject& rhs)
 {
-  if (this != &rhs)
-  {
-    if (rhs.ident() != ident()) return EC_IllegalCall;
-    *this = OFstatic_cast(const DcmElement &, rhs);
-  }
-  return EC_Normal;
+    if (this != &rhs)
+    {
+        if (rhs.ident() != ident()) return EC_IllegalCall;
+        *this = OFstatic_cast(const DcmElement &, rhs);
+    }
+    return EC_Normal;
 }
 
 
@@ -291,14 +350,32 @@ OFCondition DcmElement::detachValueField(OFBool copy)
         {
             if (!fValue)
                 l_error = loadValue();
+            if (l_error.good())
+            {
+                Uint8 * newValue;
 #ifdef HAVE_STD__NOTHROW
-            // we want to use a non-throwing new here if available
-            Uint8 * newValue = new (std::nothrow) Uint8[getLengthField()];
+                // we want to use a non-throwing new here if available
+                newValue = new (std::nothrow) Uint8[getLengthField()];
 #else
-            Uint8 * newValue = new Uint8[getLengthField()];
+                /* make sure that the pointer is set to NULL in case of error */
+                try
+                {
+                    newValue = new Uint8[getLengthField()];
+                }
+                catch (STD_NAMESPACE bad_alloc const &)
+                {
+                    newValue = NULL;
+                }
 #endif
-            memcpy(newValue, fValue, size_t(getLengthField()));
-            fValue = newValue;
+                if (newValue)
+                {
+                    memcpy(newValue, fValue, size_t(getLengthField()));
+                    fValue = newValue;
+                } else {
+                    /* the copy could not be created, so return an error */
+                    l_error = EC_MemoryExhausted;
+                }
+            }
         } else {
             fValue = NULL;
             setLengthField(0);
@@ -639,7 +716,15 @@ Uint8 *DcmElement::newValueField()
         // back to the caller.
         value = new (std::nothrow) Uint8[lengthField + 1];    // protocol error: odd value length
 #else
-        value = new Uint8[lengthField + 1];    // protocol error: odd value length
+        /* make sure that the pointer is set to NULL in case of error */
+        try
+        {
+            value = new Uint8[lengthField + 1];    // protocol error: odd value length
+        }
+        catch (STD_NAMESPACE bad_alloc const &)
+        {
+            value = NULL;
+        }
 #endif
         /* if creation was successful, set last byte to 0 (in order to initialize this byte) */
         /* (no value will be assigned to this byte later, since Length was odd) */
@@ -660,7 +745,15 @@ Uint8 *DcmElement::newValueField()
         // back to the caller.
         value = new (std::nothrow) Uint8[lengthField];
 #else
-        value = new Uint8[lengthField];
+        /* make sure that the pointer is set to NULL in case of error */
+        try
+        {
+            value = new Uint8[lengthField];
+        }
+        catch (STD_NAMESPACE bad_alloc const &)
+        {
+            value = NULL;
+        }
 #endif
     /* if creation was not successful set member error flag correspondingly */
     if (!value)
@@ -692,60 +785,70 @@ OFCondition DcmElement::changeValue(const void *value,
                                     const Uint32 position,
                                     const Uint32 num)
 {
-    OFBool done = OFFalse;
     errorFlag = EC_Normal;
+    // check for invalid parameter values
     if (position % num != 0 || getLengthField() % num != 0 || position > getLengthField())
         errorFlag = EC_IllegalCall;
     else if (position == getLengthField())
     {
+        // append value
         if (getLengthField() == 0)
         {
             errorFlag = putValue(value, num);
-            done = OFTrue;
         } else {
             // load value (if not loaded yet)
             if (!fValue)
-                loadValue();
-            // allocate new memory for value
-#ifdef HAVE_STD__NOTHROW
-            // we want to use a non-throwing new here if available.
-            // If the allocation fails, we report an EC_MemoryExhausted error
-            // back to the caller.
-            Uint8 *newValue = new (std::nothrow) Uint8[getLengthField() + num];
-#else
-            Uint8 *newValue = new Uint8[getLengthField() + num];
-#endif
-            if (!newValue)
-                errorFlag = EC_MemoryExhausted;
+                errorFlag = loadValue();
             if (errorFlag.good())
             {
-                // swap to local byte order
-                swapIfNecessary(gLocalByteOrder, fByteOrder, fValue,
-                                getLengthField(), getTag().getVR().getValueWidth());
-                fByteOrder = gLocalByteOrder;
-                // copy old value in the beginning of new value
-                memcpy(newValue, fValue, size_t(getLengthField()));
-                // set parameter value in the extension
-                memcpy(&newValue[getLengthField()], OFstatic_cast(const Uint8 *, value), size_t(num));
-#if defined(HAVE_STD__NOTHROW) && defined(HAVE_NOTHROW_DELETE)
-                // if created with the nothrow version it must also be deleted with
-                // the nothrow version else memory error.
-                operator delete[] (fValue, std::nothrow);
+                Uint8 * newValue;
+                // allocate new memory for value
+#ifdef HAVE_STD__NOTHROW
+                // we want to use a non-throwing new here if available.
+                // If the allocation fails, we report an EC_MemoryExhausted error
+                // back to the caller.
+                newValue = new (std::nothrow) Uint8[getLengthField() + num];
 #else
-                delete[] fValue;
+                /* make sure that the pointer is set to NULL in case of error */
+                try
+                {
+                    newValue = new Uint8[getLengthField() + num];
+                }
+                catch (STD_NAMESPACE bad_alloc const &)
+                {
+                    newValue = NULL;
+                }
 #endif
-                fValue = newValue;
-                setLengthField(getLengthField() + num);
+                if (!newValue)
+                    errorFlag = EC_MemoryExhausted;
+                if (errorFlag.good())
+                {
+                    // swap to local byte order
+                    swapIfNecessary(gLocalByteOrder, fByteOrder, fValue,
+                                    getLengthField(), getTag().getVR().getValueWidth());
+                    fByteOrder = gLocalByteOrder;
+                    // copy old value in the beginning of new value
+                    memcpy(newValue, fValue, size_t(getLengthField()));
+                    // copy value passed as a parameter to the end
+                    memcpy(&newValue[getLengthField()], OFstatic_cast(const Uint8 *, value), size_t(num));
+#if defined(HAVE_STD__NOTHROW) && defined(HAVE_NOTHROW_DELETE)
+                    // if created with the nothrow version it must also be deleted with
+                    // the nothrow version else memory error.
+                    operator delete[] (fValue, std::nothrow);
+#else
+                    delete[] fValue;
+#endif
+                    fValue = newValue;
+                    setLengthField(getLengthField() + num);
+                } else
+                    errorFlag = EC_MemoryExhausted;
             }
-            done = OFTrue;
         }
-    }
-    // copy value at position
-    if (!done && errorFlag.good())
-    {
+    } else {
         // swap to local byte order
         swapIfNecessary(gLocalByteOrder, fByteOrder, fValue,
                         getLengthField(), getTag().getVR().getValueWidth());
+        // copy value at given position
         memcpy(&fValue[position], OFstatic_cast(const Uint8 *, value), size_t(num));
         fByteOrder = gLocalByteOrder;
     }
