@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 1994-2014, OFFIS e.V.
+ *  Copyright (C) 1994-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -79,6 +79,7 @@ END_EXTERN_C
 #include "dcmtk/ofstd/ofcrc32.h"
 #include "dcmtk/ofstd/ofdefine.h"
 #include "dcmtk/ofstd/ofstd.h"
+#include "dcmtk/ofstd/ofnetdb.h"
 
 struct UIDNameMap {
     const char* uid;
@@ -203,6 +204,7 @@ static const UIDNameMap uidNameMap[] = {
     { UID_OphthalmicThicknessMapStorage,                       "OphthalmicThicknessMapStorage" },
     { UID_OphthalmicTomographyImageStorage,                    "OphthalmicTomographyImageStorage" },
     { UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage, "OphthalmicVisualFieldStaticPerimetryMeasurementsStorage" },
+    { UID_ParametricMapStorage,                                "ParametricMapStorage" },
     { UID_PositronEmissionTomographyImageStorage,              "PositronEmissionTomographyImageStorage" },
     { UID_ProcedureLogStorage,                                 "ProcedureLogStorage" },
     { UID_PseudoColorSoftcopyPresentationStateStorage,         "PseudoColorSoftcopyPresentationStateStorage" },
@@ -279,10 +281,10 @@ static const UIDNameMap uidNameMap[] = {
     { UID_MOVEPatientRootQueryRetrieveInformationModel,              "MOVEPatientRootQueryRetrieveInformationModel" },
     { UID_MOVEStudyRootQueryRetrieveInformationModel,                "MOVEStudyRootQueryRetrieveInformationModel" },
     { UID_RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel, "RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel" },
-    { UID_RETIRED_GETCompositeInstanceRetrieveWithoutBulkData,       "RETIRED_GETCompositeInstanceRetrieveWithoutBulkData" },
-    { UID_RETIRED_GETCompositeInstanceRootRetrieve,                  "RETIRED_GETCompositeInstanceRootRetrieve" },
+    { UID_GETCompositeInstanceRetrieveWithoutBulkData,               "GETCompositeInstanceRetrieveWithoutBulkData" },
+    { UID_GETCompositeInstanceRootRetrieve,                          "GETCompositeInstanceRootRetrieve" },
     { UID_RETIRED_GETPatientStudyOnlyQueryRetrieveInformationModel,  "RETIRED_GETPatientStudyOnlyQueryRetrieveInformationModel" },
-    { UID_RETIRED_MOVECompositeInstanceRootRetrieve,                 "RETIRED_MOVECompositeInstanceRootRetrieve" },
+    { UID_MOVECompositeInstanceRootRetrieve,                         "MOVECompositeInstanceRootRetrieve" },
     { UID_RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel, "RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel" },
 
     // Worklist
@@ -310,7 +312,8 @@ static const UIDNameMap uidNameMap[] = {
     { UID_UnifiedProcedureStepWatchSOPClass,                   "UnifiedProcedureStepWatchSOPClass" },
     { UID_UnifiedProcedureStepPullSOPClass,                    "UnifiedProcedureStepPullSOPClass" },
     { UID_UnifiedProcedureStepEventSOPClass,                   "UnifiedProcedureStepEventSOPClass" },
-    { UID_UnifiedWorklistAndProcedureStepSOPInstance,          "UnifiedWorklistAndProcedureStepSOPInstance" },
+    { UID_UPSGlobalSubscriptionSOPInstance,                    "UPSGlobalSubscriptionSOPInstance" },
+    { UID_UPSFilteredGlobalSubscriptionSOPInstance,            "UPSFilteredGlobalSubscriptionSOPInstance" },
 
     // Storage Commitment
     { UID_RETIRED_StorageCommitmentPullModelSOPClass,          "RETIRED_StorageCommitmentPullModelSOPClass" },
@@ -411,6 +414,9 @@ static const UIDNameMap uidNameMap[] = {
     { UID_RETIRED_StudyComponentManagementSOPClass,            "RETIRED_StudyComponentManagementSOPClass" },
     { UID_VerificationSOPClass,                                "VerificationSOPClass" },
 
+    // Mapping Resources
+    { UID_DICOMContentMappingResource,                         "DICOMContentMappingResource" },
+
     // Coding Schemes
     { UID_DICOMControlledTerminologyCodingScheme,              "DICOMControlledTerminologyCodingScheme" },
     { UID_DICOMUIDRegistryCodingScheme,                        "DICOMUIDRegistryCodingScheme" },
@@ -587,6 +593,7 @@ const char* dcmAllStorageSOPClassUIDs[] = {
     UID_OphthalmicThicknessMapStorage,
     UID_OphthalmicTomographyImageStorage,
     UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage,
+    UID_ParametricMapStorage,
     UID_PositronEmissionTomographyImageStorage,
     UID_ProcedureLogStorage,
     UID_PseudoColorSoftcopyPresentationStateStorage,
@@ -789,6 +796,7 @@ const char* dcmLongSCUStorageSOPClassUIDs[] = {
 //  UID_LegacyConvertedEnhancedCTImageStorage,
 //  UID_LegacyConvertedEnhancedMRImageStorage,
 //  UID_LegacyConvertedEnhancedPETImageStorage,
+//  UID_ParametricMapStorage,
 //  UID_RadiopharmaceuticalRadiationDoseSRStorage,
     // retired
     UID_RETIRED_HardcopyColorImageStorage,
@@ -960,6 +968,7 @@ const char* dcmImageSOPClassUIDs[] = {
     UID_OphthalmicPhotography8BitImageStorage,
     UID_OphthalmicThicknessMapStorage,
     UID_OphthalmicTomographyImageStorage,
+    UID_ParametricMapStorage,
     UID_PositronEmissionTomographyImageStorage,
     UID_RTImageStorage,
     UID_SecondaryCaptureImageStorage,
@@ -1082,6 +1091,7 @@ static const DcmModalityTable modalities[] = {
     { UID_OphthalmicThicknessMapStorage,                           "OPm", 768 * 576 },
     { UID_OphthalmicTomographyImageStorage,                        "OPt", 768 * 576 * 3 },
     { UID_OphthalmicVisualFieldStaticPerimetryMeasurementsStorage, "OPp", 4096 },
+    { UID_ParametricMapStorage,                                    "PM",  256 * 256 * 4 },
     { UID_PositronEmissionTomographyImageStorage,                  "PI",  512 * 512 * 2 },
     { UID_ProcedureLogStorage,                                     "SRp", 4096 },
     { UID_PseudoColorSoftcopyPresentationStateStorage,             "PSp", 4096 },
@@ -1207,9 +1217,8 @@ unsigned long dcmGuessModalityBytes(const char *sopClassUID)
 const char*
 dcmFindNameOfUID(const char* uid, const char* defaultValue)
 {
-    int i = 0;
     if (uid == NULL) return defaultValue;
-    for (i=0; i<uidNameMap_size; i++) {
+    for (int i = 0; i < uidNameMap_size; i++) {
       if (uidNameMap[i].uid != NULL && strcmp(uid, uidNameMap[i].uid) == 0) {
         return uidNameMap[i].name;
       }
@@ -1224,8 +1233,8 @@ dcmFindNameOfUID(const char* uid, const char* defaultValue)
 // Returns NULL of the name is not known.
 //
 
-const char *
-dcmFindUIDFromName(const char * name)
+const char*
+dcmFindUIDFromName(const char* name)
 {
     if (name == NULL) return NULL;
     for(int i = 0; i < uidNameMap_size; i++)
@@ -1245,9 +1254,8 @@ dcmFindUIDFromName(const char * name)
 OFBool
 dcmIsaStorageSOPClassUID(const char* uid)
 {
-    int i = 0;
     if (uid == NULL) return OFFalse;
-    for (i=0; i<numberOfAllDcmStorageSOPClassUIDs; i++) {
+    for (int i = 0; i < numberOfAllDcmStorageSOPClassUIDs; i++) {
       if (dcmAllStorageSOPClassUIDs[i] != NULL && strcmp(uid, dcmAllStorageSOPClassUIDs[i]) == 0) {
         return OFTrue;
       }
@@ -1255,10 +1263,28 @@ dcmIsaStorageSOPClassUID(const char* uid)
     return OFFalse;
 }
 
+
+/*
+** dcmIsImageStorageSOPClassUID(const char* uid)
+** Returns true if the uid is one of the Image Storage SOP Classes.
+** Performs a table lookup in the dcmImageSOPClassUIDs table.
+*/
+OFBool
+dcmIsImageStorageSOPClassUID(const char* uid)
+{
+    if (uid == NULL) return OFFalse;
+    for (int i = 0; i < numberOfDcmImageSOPClassUIDs; i++) {
+      if (dcmImageSOPClassUIDs[i] != NULL && strcmp(uid, dcmImageSOPClassUIDs[i]) == 0) {
+        return OFTrue;
+      }
+    }
+    return OFFalse;
+}
+
 // ********************************
 
 #ifndef HAVE_GETHOSTID
-#ifdef HAVE_SYSINFO
+#if defined(HAVE_SYSINFO) && defined(HAVE_SYS_SYSTEMINFO_H)
 
 #include <sys/systeminfo.h>
 static long gethostid(void)
@@ -1421,7 +1447,7 @@ static unsigned char *getMACAddress(unsigned char buffer[6])
                 varBindList.list = varBind;
                 varBind[0].name = MIB_NULL;
                 varBind[1].name = MIB_NULL;
-                /* copy in the OID to find the number of entries in the inteface table */
+                /* copy in the OID to find the number of entries in the interface table */
                 varBindList.len = 1;        /* only retrieving one item */
                 m_Copy(&varBind[0].name, &MIB_ifEntryNum);
                 ret = m_Query(SNMP_PDU_GETNEXT, &varBindList, &errorStatus, &errorIndex);
@@ -1507,7 +1533,6 @@ static long gethostid(void)
     long result = 0;
 #if (defined(HAVE_GETHOSTNAME) && defined(HAVE_GETHOSTBYNAME)) || defined(HAVE_WINDOWS_H)
     char name[1024];
-    struct hostent *hent = NULL;
     char **p = NULL;
     struct in_addr in;
 #ifdef HAVE_WINSOCK_H
@@ -1522,21 +1547,12 @@ static long gethostid(void)
     */
     if (gethostname(name, 1024) == 0)
     {
-#if defined(HAVE_GETHOSTBYNAME_R)
-        // use gethostbyname_r instead of gethostbyname
-        int h_errnop=0;
-        struct hostent theHostent;
-        char buffer[GETHOSTBYNAME_R_BUFSIZE];
-        if ((hent = gethostbyname_r(name, &theHostent, buffer, GETHOSTBYNAME_R_BUFSIZE, &h_errnop)) != NULL)
-#else
-        if ((hent = gethostbyname(name)) != NULL)
-#endif
+        if (OFStandard::OFHostent hent = OFStandard::getHostByName(name))
         {
-            p = hent->h_addr_list;
-            if (p && *p)
+            if (!hent.h_addr_list.empty())
             {
-                (void) memcpy(&in.s_addr, *p, sizeof(in.s_addr));
-                result = (long)in.s_addr;
+                memcpy(&in.s_addr, hent.h_addr_list.front().c_str(), sizeof(in.s_addr));
+                result = OFstatic_cast(long, in.s_addr);
             }
         }
     }
@@ -1653,13 +1669,13 @@ initCounterOfCurrentUID()
 static char*
 stripTrailing(char* s, char c)
 {
-    size_t i, n;
-
     if (s == NULL) return s;
-
-    n = strlen(s);
-    for (i = n - 1; (i >= 0) && (s[i] == c); i--)
-        s[i] = '\0';
+    for
+    (
+        char* it = s + strlen(s) - 1;
+        it >= s && *it == c;
+        *it-- = '\0'
+    );
     return s;
 }
 
