@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2007-2015, OFFIS e.V.
+ *  Copyright (C) 2007-2011, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -473,12 +473,12 @@ OFCondition DJLSEncoderBase::losslessRawEncode(
   // create initial pixel sequence
   if (result.good())
   {
-    pixelSequence = new DcmPixelSequence(DCM_PixelSequenceTag);
+    pixelSequence = new DcmPixelSequence(DcmTag(DCM_PixelData,EVR_OB));
     if (pixelSequence == NULL) result = EC_MemoryExhausted;
     else
     {
       // create empty offset table
-      offsetTable = new DcmPixelItem(DCM_PixelItemTag);
+      offsetTable = new DcmPixelItem(DcmTag(DCM_Item,EVR_OB));
       if (offsetTable == NULL) result = EC_MemoryExhausted;
       else pixelSequence->insert(offsetTable);
     }
@@ -766,12 +766,12 @@ OFCondition DJLSEncoderBase::losslessCookedEncode(
   // create initial pixel sequence
   if (result.good())
   {
-    pixelSequence = new DcmPixelSequence(DCM_PixelSequenceTag);
+    pixelSequence = new DcmPixelSequence(DcmTag(DCM_PixelData,EVR_OB));
     if (pixelSequence == NULL) result = EC_MemoryExhausted;
     else
     {
       // create empty offset table
-      offsetTable = new DcmPixelItem(DCM_PixelItemTag);
+      offsetTable = new DcmPixelItem(DcmTag(DCM_Item,EVR_OB));
       if (offsetTable == NULL) result = EC_MemoryExhausted;
       else pixelSequence->insert(offsetTable);
     }
