@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2003-2015, OFFIS e.V.
+ *  Copyright (C) 2003-2010, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -104,29 +104,6 @@ void DcmPresentationContextMap::clear()
   }
 }
 
-
-OFMap<OFString, DcmPresentationContextList*>::const_iterator DcmPresentationContextMap::begin()
-{
-  return map_.begin();
-}
-
-
-OFMap<OFString, DcmPresentationContextList*>::const_iterator DcmPresentationContextMap::end()
-{
-  return map_.end();
-}
-
-const DcmPresentationContextList* DcmPresentationContextMap::getPresentationContextList(const OFString& pcName)
-{
-  OFMap<OFString,DcmPresentationContextList*>::const_iterator it = map_.find(pcName);
-  if ( it == map_.end() )
-  {
-    return NULL;
-  }
-  else
-    return (*it).second;
-}
-
 OFCondition DcmPresentationContextMap::add(
   const char *key,
   const char *abstractSyntaxUID,
