@@ -99,8 +99,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
 
     /** read SR document from DICOM dataset.
      *  Please note that the current document is also deleted if the reading process fails.
-     *  If logging is enabled, the reason for any error might be obtained from the error/warning
-     *  output.
+     *  If logging is enabled, the reason for any error might be obtained from the log output.
+     *  Also warning and debug messages are reported if the respective logger is enabled.
      ** @param  dataset  reference to DICOM dataset from which the document should be read
      *  @param  flags    optional flag used to customize the reading process (see DSRTypes::RF_xxx).
      *                   E.g. RF_readDigitalSignatures indicates whether to read the digital
@@ -108,8 +108,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *                   and the DigitalSignaturesSequence are read for the general document
      *                   header (equivalent to top-level content item) and each content item
      *                   of the document tree.
-     *                   If not removed manually (with 'DSRDocumentTree::removeSignatures')
-     *                   the signatures are written back to the dataset when the method 'write'
+     *                   If not removed manually (with DSRDocumentTree::removeSignatures())
+     *                   the signatures are written back to the dataset when the write() method
      *                   is called.
      *                   Please note that the two signature sequences for any other sequence
      *                   (e.g. VerifyingObserver or PredecessorDocuments) are never read.
@@ -123,7 +123,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  member variable section of this class.  Other data is not changed, so be careful
      *  when using this method.
      *  @param  dataset  reference to DICOM dataset from which the data should be read
-     *  @return status, EC_Normal if successful, an error code otherwise
+     ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readPatientData(DcmItem &dataset);
 
@@ -132,7 +132,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  "General Study Module" in the member variable section of this class.  Other data
      *  is not changed, so be careful when using this method.
      *  @param  dataset  reference to DICOM dataset from which the data should be read
-     *  @return status, EC_Normal if successful, an error code otherwise
+     ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition readStudyData(DcmItem &dataset);
 
@@ -142,6 +142,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Instead, the template identification has to be set manually for the root CONTAINER
      *  (see DSRDocumentTreeNode::setTemplateIdentification()).  This is because the template
      *  constraints cannot be checked yet.
+     *  If logging is enabled, warning and debug messages are reported to the log output.
      ** @param  dataset      reference to DICOM dataset to which the current document should be
      *                       written.  The 'dataset' is not cleared before writing to it!
      *  @param  markedItems  optional stack where pointers to all 'marked' content items
@@ -218,7 +219,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSpecificCharacterSetType(const E_CharacterSet characterSet);
 
     /** get document preliminary flag.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return preliminary flag (might be PF_invalid if not specified)
      */
     virtual E_PreliminaryFlag getPreliminaryFlag() const;
@@ -234,13 +235,13 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get document completion flag.
      *  According to the DICOM standard, this flag describes the estimated degree of completeness
      *  of an SR Document.  See DICOM standard for details.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return completion flag (might be CF_invalid if read from dataset)
      */
     virtual E_CompletionFlag getCompletionFlag() const;
 
     /** get document verification flag.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return verification flag (might be VF_invalid if read from dataset)
      */
     virtual E_VerificationFlag getVerificationFlag() const;
@@ -249,7 +250,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  A document can be verified more than once.  The verification flag should be VERIFIED
      *  if any verifying observer is specified.  The details on the observer can be retrieved
      *  using the getVerifyingObserver() methods.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return number of verifying observers (if any), 0 otherwise
      */
     virtual size_t getNumberOfVerifyingObservers();
@@ -257,7 +258,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get information about a verifying observer.
      *  All reference variables are cleared before the information is retrieved, i.e. if an error
      *  occurs (return value != EC_Normal) non-empty variables do contain valid (empty) data.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  idx           index of the verifying observer to be retrieved (starting with 1).
      *                        Use getNumberOfVerifyingObservers() to get the maximum value.
      *  @param  dateTime      reference to variable where the date and time when this document
@@ -276,7 +277,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** get information about a verifying observer.
      *  All reference variables are cleared before the information is retrieved, i.e. if an error
      *  occurs (return value != EC_Normal) non-empty variables do contain valid (empty) data.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  idx           index of the verifying observer to be retrieved (starting with 1).
      *                        Use getNumberOfVerifyingObservers() to get the maximum value.
      *  @param  dateTime      reference to variable where the date and time when this document
@@ -304,7 +305,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  included in this document with or without modification." and "[...] the use of the
      *  Predecessor Document Sequence allows tracing back to the input SR Document, which in this
      *  case is the previous version."
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return reference to list object
      */
     virtual DSRSOPInstanceReferenceList &getPredecessorDocuments();
@@ -345,7 +346,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  reference all other evidence considered pertinent for this SR Document that is not listed
      *  in the Current Requested Procedure Evidence Sequence.  This requires that the same SOP
      *  Instance shall not be referenced in both of these Sequences."
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return reference to list object
      */
     virtual DSRSOPInstanceReferenceList &getPertinentOtherEvidence();
@@ -356,15 +357,15 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  to the current SOP Instance is known at the time of creation of this SOP instance. May be
      *  present otherwise."  Note: An equivalent rendering of the document might be provided as an
      *  "Encapsulated PDF" DICOM object.
-     *  Not applicable to Key Object Selection Documents.
-     *  @return reference to list object
+     *  @note Not applicable to Key Object Selection Documents.
+     ** @return reference to list object
      */
     virtual DSRReferencedInstanceList &getReferencedInstances();
 
     /** get list of coding schemes used (Coding Scheme Identification).
      *  The Coding Scheme Identification Sequence maps Coding Scheme Designators to an external coding
      *  system registration, or to a private or local coding scheme.  See DICOM standard for details.
-     *  @return reference to list object
+     ** @return reference to list object
      */
     virtual DSRCodingSchemeIdentificationList &getCodingSchemeIdentification();
 
@@ -380,7 +381,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
                                                 const signed long pos = 0) const;
 
     /** get completion flag description.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
      ** @return status, EC_Normal if successful, an error code otherwise
@@ -484,6 +485,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition getSeriesDescription(OFString &value,
                                              const signed long pos = 0) const;
 
+    /** get protocol name
+     ** @param  value  reference to variable in which the value should be stored
+     *  @param  pos    index of the value to get (0..vm-1), -1 for all components
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition getProtocolName(OFString &value,
+                                        const signed long pos = 0) const;
+
     /** get manufacturer
      ** @param  value  reference to variable in which the value should be stored
      *  @param  pos    index of the value to get (0..vm-1), -1 for all components
@@ -634,7 +643,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
                                                 const OFBool check = OFTrue);
 
     /** set completion flag description.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  value  explanation of the value that is set for completion flag.  If an empty
      *                 string is passed, the description is removed from the dataset (type 3).
      *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
@@ -691,6 +700,14 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     virtual OFCondition setSeriesDescription(const OFString &value,
                                              const OFBool check = OFTrue);
 
+    /** set protocol name
+     ** @param  value  value to be set (single value only) or "" for no value
+     *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setProtocolName(const OFString &value,
+                                        const OFBool check = OFTrue);
+
     /** set manufacturer
      ** @param  value  value to be set (single value only) or "" for no value
      *  @param  check  check 'value' for conformance with VR (LO) and VM (1) if enabled
@@ -874,11 +891,22 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     /** create a new document of the specified type.
      *  A new SOP instance is only created if the current document type was valid/supported.
      *  Please note that the current document is deleted by this method.
-     ** @param  documentType  type of the SR document (see DSRTypes::E_DocumentType)
+     ** @param  documentType  type of the new SR document (see DSRTypes::E_DocumentType)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition createNewDocument(const E_DocumentType documentType);
 
+    /** change the type of the current document.
+     *  Please note that only the type of the SR document is changed (if possible) but no new
+     *  SOP instance is created.  If needed, this has to be done with createNewSOPInstance()
+     *  in addition to this method or by calling createNewDocument() instead of this method.
+     *  Before changing the document type, it is checked whether the currently stored document
+     *  tree complies with the relationship content constraints of the new SR IOD.
+     ** @param  documentType  new type of the SR document (see DSRTypes::E_DocumentType)
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition changeDocumentType(const E_DocumentType documentType);
+
     /** create a revised version of the current document.
      *  A revised version can only be created if the current document is already completed
      *  (see completion flag).  If so, a reference to the current document is added to the
@@ -893,9 +921,10 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  reset (OFFalse).  The preliminary flag is not modified by this method.  Also the
      *  various lists of referenced instances remain unchanged, i.e. they have to be
      *  adapted manually if needed.
-     *  Not applicable to Key Object Selection Documents.
-     *  @param clearList clear list of predecessor documents before adding the current
-     *    document if OFTrue. Append current document to existing list otherwise.
+     *  @note Not applicable to Key Object Selection Documents.
+     *  @param  clearList  clear list of predecessor documents before adding the current
+     *                     document if OFTrue.  Append current document to existing list
+     *                     otherwise.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition createRevisedVersion(const OFBool clearList = OFTrue);
@@ -905,7 +934,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  describes the estimated degree of completeness of an SR Document (see DICOM standard
      *  for details).  The completion flag description is set to an empty string (i.e. absent
      *  in DICOM dataset).
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition completeDocument();
@@ -915,7 +944,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  describes the estimated degree of completeness of an SR Document (see DICOM standard
      *  for details).  The completion flag description can be modified independently from the
      *  flag by means of the method setCompletionFlagDescription() - see above.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  description  explanation of the value set for completion flag.
      *                       (optional, see previous method, VR=LO)
      *  @param  check        check 'description' for conformance with VR and VM if enabled
@@ -931,7 +960,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Please note that only completed documents (see completion flag) can be verified and that
      *  a new SOP instance UID has to be generated (manually) according to the DICOM standard when
      *  creating a dataset/file from this document.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  observerName  name of the person who has verified this document (required, VR=PN)
      *  @param  organization  name of the organization to which the observer belongs (required, VR=LO)
      *  @param  dateTime      verification date time (optional). If empty/absent the current date and
@@ -952,7 +981,7 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *  Please note that only completed documents (see completion flag) can be verified and that
      *  a new SOP instance UID has to be generated (manually) according to the DICOM standard when
      *  creating a dataset/file from this document.
-     *  Not applicable to Key Object Selection Documents.
+     *  @note Not applicable to Key Object Selection Documents.
      ** @param  observerName  name of the person who has verified this document (required, VR=PN)
      *  @param  observerCode  code identifying the verifying observer (optional, see previous method)
      *  @param  organization  name of the organization to which the observer belongs (required, VR=LO)
@@ -985,9 +1014,9 @@ class DCMTK_DCMSR_EXPORT DSRDocument
      *      document management functions do reset the flag (i.e. set the FinalizedFlag to OFFalse),
      *      other methods (e.g. setXXX) do not change the flag though the state of the document is
      *      not finalized any more after they have been called.
-     *  Not applicable to Key Object Selection Documents since there's no completion flag in this
-     *  type of SR document.  Please note that this method has nothing to do with the preliminary
-     *  flag.
+     *  @note Not applicable to Key Object Selection Documents since there's no completion flag in
+     *        this type of SR document.  Please note that this method has nothing to do with the
+     *        preliminary flag.
      ** @return status, EC_Normal if successful, an error code otherwise
      */
     virtual OFCondition finalizeDocument();
@@ -1198,11 +1227,11 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     // Software Version(s): (LO, 1-n, 1)
     // - see 'General Equipment Module'
 
-    // --- Frame of Reference (C) ---
+    // --- Synchronization Module (C/U - for some IODs) ---
 
-    // tbd: conditional module for X-Ray Radiation Dose SR not yet supported
+    // tbd: conditional/optional module not yet supported
 
-    // --- SR Document Series Module (M) ---
+    // --- SR Document Series / Key Object Document Series Module (M) ---
 
     /// Modality: (CS, 1, 1)
     DcmCodeString       Modality;
@@ -1214,6 +1243,8 @@ class DCMTK_DCMSR_EXPORT DSRDocument
     DcmDate             SeriesDate;
     /// Series Time: (TM, 1, 3)
     DcmTime             SeriesTime;
+    /// Protocol Name: (LO, 1, 3)
+    DcmLongString       ProtocolName;
     /// Series Description: (LO, 1, 3)
     DcmLongString       SeriesDescription;
     /// Referenced Performed Procedure Step Sequence: (SQ, 1, 2)
