@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -38,6 +38,13 @@
 class DSRIODConstraintChecker;
 
 
+/*-------------------*
+ *  type definition  *
+ *-------------------*/
+
+typedef DSRTreeNodeCursor<DSRDocumentTreeNode> DSRDocumentTreeNodeCursor;
+
+
 /*---------------------*
  *  class declaration  *
  *---------------------*/
@@ -47,28 +54,50 @@ class DSRIODConstraintChecker;
 class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
   : public DSRTreeNode
 {
+    // allow direct access to protected methods
+    friend class DSRTree<DSRDocumentTreeNode>;
+    friend class DSRTreeNodeCursor<DSRDocumentTreeNode>;
+
     // allow access to getConceptNamePtr()
     friend class DSRContentItem;
 
   public:
 
     /** constructor.
-     *  The 'relationshipType' and 'valueType' can never be changed after the tree node
-     *  has been created (therefore, the corresponding member variables are declared
-     *  "const").
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid and RT_isRoot only for the
-     *                            root node.
-     *  @param  valueType         value type of the associated content item.
-     *                            Should not be VT_invalid.
+     *  The 'valueType' can never be changed after the tree node has been created
+     *  (therefore, the corresponding member variable is declared "const").
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid, and DSRTypes::RT_isRoot
+     *                            only for the root node.
+     *  @param  valueType         value type of the associated content item.  Should not
+     *                            be DSRTypes::VT_invalid.
      */
     DSRDocumentTreeNode(const E_RelationshipType relationshipType,
                         const E_ValueType valueType);
 
+    /** copy constructor.
+     *  Please note that the member variables of the base class DSRTreeNode are not copied
+     *  because the new tree node is not (yet) part of a document tree.  Furthermore, the
+     *  following member variables of this class are also not copied but initialized with
+     *  their respective default values:
+     *  - ReferenceTarget
+     *  - MACParameters
+     *  - DigitalSignatures
+     *
+     ** @param  node  tree node to be copied
+     */
+    DSRDocumentTreeNode(const DSRDocumentTreeNode &node);
+
     /** destructor
      */
     virtual ~DSRDocumentTreeNode();
 
+    /** clone this tree node (abstract).
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRDocumentTreeNode *clone() const = 0;
+
     /** clear all member variables.
      *  This does not apply to the relationship and value type since they are never changed.
      */
@@ -174,10 +203,10 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
     }
 
     /** check whether content item is marked.
-     *  Use method 'setMark' to mark and unmark the current content item.
+     *  Use method setMark() to mark and unmark the current content item.
      *  Pointers to the DICOM dataset/item of marked content items are added to the optional
-     *  stack when calling the 'write' method.  This mechanism can e.g. be used to digitally
-     *  sign particular content items.
+     *  stack when calling the DSRDocument::write() method.  This mechanism can e.g. be used
+     *  to digitally sign particular content items.
      ** @return OFTrue if content item is marked, OFFalse otherwise
      */
     inline OFBool isMarked() const
@@ -186,7 +215,7 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
     }
 
     /** mark/unmark the current content item.
-     *  See explanation for method 'isMarked' for details.
+     *  See explanation for method isMarked() for details.
      *  @param  flag  mark item if OFTrue, unmark otherwise
      */
     inline void setMark(const OFBool flag)
@@ -215,7 +244,7 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
      */
     inline OFBool hasChildNodes() const
     {
-        return (Down != NULL);
+        return (getDown() != NULL);
     }
 
     /** check whether the current content item has any siblings
@@ -223,7 +252,7 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
      */
     inline OFBool hasSiblingNodes() const
     {
-        return (Prev != NULL) || (Next != NULL);
+        return (getPrev() != NULL) || (getNext() != NULL);
     }
 
     /** get ID of the current tree node
@@ -231,19 +260,31 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
      */
     inline size_t getNodeID() const
     {
-        return Ident;
+        return getIdent();
     }
 
     /** get relationship type of the current content item
-     ** @return relationship type of the current content item (might be RT_invalid)
+     ** @return relationship type of the current content item (might be DSRTypes::RT_invalid)
      */
     inline E_RelationshipType getRelationshipType() const
     {
         return RelationshipType;
     }
 
+    /** set relationship type of the current content item (if previously unknown).
+     *  Please note that changing the relationship type (which was originally passed to the
+     *  constructor of this class) only works if the current value is DSRTypes::RT_unknown.
+     *  This is needed for inserting document subtrees where the top-level nodes might have an
+     *  "unknown" relationship to the parent node (see DSRDocumentSubTree::insertSubTree()).
+     ** @param  relationshipType  type of relationship to the parent tree node.
+     *                            Should not be DSRTypes::RT_invalid, DSRTypes::RT_unknown or
+     *                            DSRTypes::RT_isRoot.
+     ** @return status, EC_Normal if successful, an error code otherwise
+     */
+    virtual OFCondition setRelationshipType(const E_RelationshipType relationshipType);
+
     /** get value type of the current content item
-     ** @return value type of the current content item (might be VT_invalid)
+     ** @return value type of the current content item (might be DSRTypes::VT_invalid)
      */
     inline E_ValueType getValueType() const
     {
@@ -264,7 +305,7 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
      ** @param  conceptName  reference to a variable where the code should be stored
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition getConceptName(DSRCodedEntryValue &conceptName) const;
+    virtual OFCondition getConceptName(DSRCodedEntryValue &conceptName) const;
 
     /** set the concept name.
      *  Code describing the concept represented by this content item.  Also conveys the value
@@ -326,19 +367,20 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
      *  (and its children).  According to the DICOM standard it is "required if a template
      *  was used to define the content of this Item, and the template consists of a single
      *  CONTAINER with nested content, and it is the outermost invocation of a set of
-     *  nested templates that start with the same CONTAINER."  However, this condition is
-     *  currently not checked.  The identification is valid if both values are either present
-     *  (non-empty) or absent (empty).
+     *  nested templates that start with the same CONTAINER."  The identification is valid
+     *  if both values are either present (non-empty) or absent (empty).
      ** @param  templateIdentifier  identifier of the template (might be empty)
      *  @param  mappingResource     mapping resource that defines the template (might be empty)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition getTemplateIdentification(OFString &templateIdentifier,
-                                          OFString &mappingResource) const;
+    virtual OFCondition getTemplateIdentification(OFString &templateIdentifier,
+                                                  OFString &mappingResource) const;
 
     /** set template identifier and mapping resource.
      *  The identification is valid if both values are either present (non-empty) or absent
      *  (empty).  See getTemplateIdentification() for details.
+     *  A warning message is reported to the logger if a template identification is specified
+     *  for a content item that is not a CONTAINER.
      ** @param  templateIdentifier  identifier of the template to be set
      *  @param  mappingResource     mapping resource that defines the template
      *  @param  check               check 'templateIdentifier' and 'mappingResource' for
@@ -366,6 +408,38 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
         return &ConceptName;
     }
 
+    /** get pointer to previous tree node
+     ** @return pointer to previous tree node (might be NULL)
+     */
+    inline DSRDocumentTreeNode *getPrev() const
+    {
+        return OFstatic_cast(DSRDocumentTreeNode *, DSRTreeNode::getPrev());
+    }
+
+    /** get pointer to next tree node
+     ** @return pointer to next tree node (might be NULL)
+     */
+    inline DSRDocumentTreeNode *getNext() const
+    {
+        return OFstatic_cast(DSRDocumentTreeNode *, DSRTreeNode::getNext());
+    }
+
+    /** get pointer to first child node
+     ** @return pointer to first child node (might be NULL)
+     */
+    inline DSRDocumentTreeNode *getDown() const
+    {
+        return OFstatic_cast(DSRDocumentTreeNode *, DSRTreeNode::getDown());
+    }
+
+    /** get unique identifier of this node
+     ** @return unique identifier of this node
+     */
+    inline size_t getIdent() const
+    {
+        return DSRTreeNode::getIdent();
+    }
+
     /** create a new node and append it to the current one
      ** @param  previousNode       reference to the pointer to the previous node (sibling).
      *                             Used to decide whether the new node is a child (value=NULL)
@@ -560,38 +634,38 @@ class DCMTK_DCMSR_EXPORT DSRDocumentTreeNode
 
   private:
 
-    /// flag indicating whether the content item is marked (e.g. used for digital signatures)
-    OFBool                   MarkFlag;
+    /// flag indicating whether the content item is marked (e.g. used for digital signatures).
+    /// The default value is OFFalse.
+    OFBool             MarkFlag;
     /// flag indicating whether the content item is referenced (by-reference relationship)
-    OFBool                   ReferenceTarget;
+    /// The default value is OFFalse.
+    OFBool             ReferenceTarget;
 
     /// relationship type to the parent node (associated DICOM VR=CS, mandatory)
-    const E_RelationshipType RelationshipType;
+    E_RelationshipType RelationshipType;
     /// value type (associated DICOM VR=CS, mandatory)
-    const E_ValueType        ValueType;
+    const E_ValueType  ValueType;
 
     /// concept name (VR=SQ, conditional)
-    DSRCodedEntryValue       ConceptName;
+    DSRCodedEntryValue ConceptName;
     /// observation date/time (VR=DT, conditional)
-    OFString                 ObservationDateTime;
+    OFString           ObservationDateTime;
     /// observation unique identifier (VR=UI, optional)
-    OFString                 ObservationUID;
+    OFString           ObservationUID;
 
     /// template identifier (VR=CS, mandatory in ContentTemplateSequence)
-    OFString                 TemplateIdentifier;
+    OFString           TemplateIdentifier;
     /// mapping resource (VR=CS, mandatory in ContentTemplateSequence)
-    OFString                 MappingResource;
+    OFString           MappingResource;
 
     /// MAC parameters sequence (VR=SQ, optional)
-    DcmSequenceOfItems       MACParameters;
+    DcmSequenceOfItems MACParameters;
     /// digital signatures sequence (VR=SQ, optional)
-    DcmSequenceOfItems       DigitalSignatures;
+    DcmSequenceOfItems DigitalSignatures;
 
-
- // --- declaration of default/copy constructor and assignment operator
+ // --- declaration of default constructor and assignment operator
 
     DSRDocumentTreeNode();
-    DSRDocumentTreeNode(const DSRDocumentTreeNode &);
     DSRDocumentTreeNode &operator=(const DSRDocumentTreeNode &);
 };
 
