@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,15 +44,28 @@ class DCMTK_DCMSR_EXPORT DSRNumTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      */
     DSRNumTreeNode(const E_RelationshipType relationshipType);
 
+    /** copy constructor.
+     *  Please note that the comments on the copy constructor of the base class
+     *  DSRDocumentTreeNode apply.
+     ** @param  node  tree node to be copied
+     */
+    DSRNumTreeNode(const DSRNumTreeNode &node);
+
     /** destructor
      */
     virtual ~DSRNumTreeNode();
 
+    /** clone this tree node.
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRNumTreeNode *clone() const;
+
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
@@ -123,10 +136,9 @@ class DCMTK_DCMSR_EXPORT DSRNumTreeNode
 
   private:
 
- // --- declaration of default/copy constructor and assignment operator
+ // --- declaration of default constructor and assignment operator
 
     DSRNumTreeNode();
-    DSRNumTreeNode(const DSRNumTreeNode &);
     DSRNumTreeNode &operator=(const DSRNumTreeNode &);
 };
 
