@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,14 +44,14 @@ class DCMTK_DCMSR_EXPORT DSRPNameTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      */
     DSRPNameTreeNode(const E_RelationshipType relationshipType);
 
     /** constructor
      ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     *                            Should not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      *  @param  personNameValue   initial value to be set (VR=PN, mandatory)
      *  @param  check             if enabled, check 'personNameValue' for validity before
      *                            setting it.  See checkValue() for details.  An empty value
@@ -61,6 +61,19 @@ class DCMTK_DCMSR_EXPORT DSRPNameTreeNode
                      const OFString &personNameValue,
                      const OFBool check = OFTrue);
 
+    /** copy constructor.
+     *  Please note that the comments on the copy constructor of the base class
+     *  DSRDocumentTreeNode apply.
+     ** @param  node  tree node to be copied
+     */
+    DSRPNameTreeNode(const DSRPNameTreeNode &node);
+
+    /** clone this tree node.
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRPNameTreeNode *clone() const;
+
     /** destructor
      */
     virtual ~DSRPNameTreeNode();
@@ -158,10 +171,9 @@ class DCMTK_DCMSR_EXPORT DSRPNameTreeNode
 
   private:
 
- // --- declaration of default/copy constructor and assignment operator
+ // --- declaration of default constructor and assignment operator
 
     DSRPNameTreeNode();
-    DSRPNameTreeNode(const DSRPNameTreeNode &);
     DSRPNameTreeNode &operator=(const DSRPNameTreeNode &);
 };
 
