@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2010-2012, OFFIS e.V.
+ *  Copyright (C) 2010-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,7 +26,7 @@
 
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
-#include "dcmtk/dcmsr/dsrdoctr.h"
+#include "dcmtk/dcmsr/dsrdoctn.h"
 #include "dcmtk/dcmsr/dsrsc3vl.h"
 
 
@@ -44,15 +44,28 @@ class DCMTK_DCMSR_EXPORT DSRSCoord3DTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      */
     DSRSCoord3DTreeNode(const E_RelationshipType relationshipType);
 
+    /** copy constructor.
+     *  Please note that the comments on the copy constructor of the base class
+     *  DSRDocumentTreeNode apply.
+     ** @param  node  tree node to be copied
+     */
+    DSRSCoord3DTreeNode(const DSRSCoord3DTreeNode &node);
+
     /** destructor
      */
     virtual ~DSRSCoord3DTreeNode();
 
+    /** clone this tree node.
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRSCoord3DTreeNode *clone() const;
+
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
@@ -65,7 +78,7 @@ class DCMTK_DCMSR_EXPORT DSRSCoord3DTreeNode
     virtual OFBool isValid() const;
 
     /** check whether the content is short.
-     *  The method isShort() from the base class DSRSpatialCoordinatesValue is called.
+     *  The method isShort() from the base class DSRSpatialCoordinates3DValue is called.
      ** @param  flags  flag used to customize the output (see DSRTypes::HF_xxx)
      ** @return OFTrue if the content is short, OFFalse otherwise
      */
@@ -130,10 +143,9 @@ class DCMTK_DCMSR_EXPORT DSRSCoord3DTreeNode
 
   private:
 
-// --- declaration of default/copy constructor and assignment operator
+// --- declaration of default constructor and assignment operator
 
     DSRSCoord3DTreeNode();
-    DSRSCoord3DTreeNode(const DSRSCoord3DTreeNode &);
     DSRSCoord3DTreeNode &operator=(const DSRSCoord3DTreeNode &);
 };
 
