@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,14 +44,14 @@ class DCMTK_DCMSR_EXPORT DSRTimeTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      */
     DSRTimeTreeNode(const E_RelationshipType relationshipType);
 
     /** constructor
      ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     *                            Should not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      *  @param  timeValue         initial value to be set (VR=TM, mandatory)
      *  @param  check             if enabled, check 'timeValue' for validity before setting
      *                            it.  See checkValue() for details.  An empty value is never
@@ -61,10 +61,23 @@ class DCMTK_DCMSR_EXPORT DSRTimeTreeNode
                     const OFString &timeValue,
                     const OFBool check = OFTrue);
 
+    /** copy constructor.
+     *  Please note that the comments on the copy constructor of the base class
+     *  DSRDocumentTreeNode apply.
+     ** @param  node  tree node to be copied
+     */
+    DSRTimeTreeNode(const DSRTimeTreeNode &node);
+
     /** destructor
      */
     virtual ~DSRTimeTreeNode();
 
+    /** clone this tree node.
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRTimeTreeNode *clone() const;
+
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
@@ -159,10 +172,9 @@ class DCMTK_DCMSR_EXPORT DSRTimeTreeNode
 
   private:
 
- // --- declaration of default/copy constructor and assignment operator
+ // --- declaration of default constructor and assignment operator
 
     DSRTimeTreeNode();
-    DSRTimeTreeNode(const DSRTimeTreeNode &);
     DSRTimeTreeNode &operator=(const DSRTimeTreeNode &);
 };
 
