@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -44,14 +44,14 @@ class DCMTK_DCMSR_EXPORT DSRUIDRefTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      */
     DSRUIDRefTreeNode(const E_RelationshipType relationshipType);
 
     /** constructor.
      ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     *                            Should not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      *  @param  uidValue          initial value to be set (VR=UI, mandatory)
      *  @param  check             if enabled, check 'uidValue' for validity before setting
      *                            it.  See checkValue() for details.  An empty value is never
@@ -61,10 +61,23 @@ class DCMTK_DCMSR_EXPORT DSRUIDRefTreeNode
                       const OFString &uidValue,
                       const OFBool check = OFTrue);
 
+    /** copy constructor.
+     *  Please note that the comments on the copy constructor of the base class
+     *  DSRDocumentTreeNode apply.
+     ** @param  node  tree node to be copied
+     */
+    DSRUIDRefTreeNode(const DSRUIDRefTreeNode &node);
+
     /** destructor
      */
     virtual ~DSRUIDRefTreeNode();
 
+    /** clone this tree node.
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRUIDRefTreeNode *clone() const;
+
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
@@ -143,10 +156,9 @@ class DCMTK_DCMSR_EXPORT DSRUIDRefTreeNode
 
   private:
 
- // --- declaration of default/copy constructor and assignment operator
+ // --- declaration of default constructor and assignment operator
 
     DSRUIDRefTreeNode();
-    DSRUIDRefTreeNode(const DSRUIDRefTreeNode &);
     DSRUIDRefTreeNode &operator=(const DSRUIDRefTreeNode &);
 };
 
