@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -26,7 +26,7 @@
 
 #include "dcmtk/config/osconfig.h"   /* make sure OS specific configuration is included first */
 
-#include "dcmtk/dcmsr/dsrdoctr.h"
+#include "dcmtk/dcmsr/dsrdoctn.h"
 #include "dcmtk/dcmsr/dsrwavvl.h"
 
 
@@ -44,15 +44,28 @@ class DCMTK_DCMSR_EXPORT DSRWaveformTreeNode
   public:
 
     /** constructor
-     ** @param  relationshipType  type of relationship to the parent tree node.
-     *                            Should not be RT_invalid or RT_isRoot.
+     ** @param  relationshipType  type of relationship to the parent tree node.  Should
+     *                            not be DSRTypes::RT_invalid or DSRTypes::RT_isRoot.
      */
     DSRWaveformTreeNode(const E_RelationshipType relationshipType);
 
+    /** copy constructor.
+     *  Please note that the comments on the copy constructor of the base class
+     *  DSRDocumentTreeNode apply.
+     ** @param  node  tree node to be copied
+     */
+    DSRWaveformTreeNode(const DSRWaveformTreeNode &node);
+
     /** destructor
      */
     virtual ~DSRWaveformTreeNode();
 
+    /** clone this tree node.
+     *  Internally, the copy constructor is used, so the corresponding comments apply.
+     ** @return copy of this tree node
+     */
+    virtual DSRWaveformTreeNode *clone() const;
+
     /** clear all member variables.
      *  Please note that the content item might become invalid afterwards.
      */
@@ -130,10 +143,9 @@ class DCMTK_DCMSR_EXPORT DSRWaveformTreeNode
 
   private:
 
-// --- declaration of default/copy constructor and assignment operator
+// --- declaration of default constructor and assignment operator
 
     DSRWaveformTreeNode();
-    DSRWaveformTreeNode(const DSRWaveformTreeNode &);
     DSRWaveformTreeNode &operator=(const DSRWaveformTreeNode &);
 };
 
