@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRContentItem
@@ -55,13 +55,26 @@ const DSRWaveformReferenceValue    DSRContentItem::EmptyWaveformReference;
 
 DSRContentItem::DSRContentItem()
   : TreeNode(NULL),
+    DeleteTreeNode(OFFalse),
     EmptyNumericMeasurement()
 {
 }
 
 
+DSRContentItem::DSRContentItem(const DSRContentItem &item)
+  : TreeNode(NULL),
+    DeleteTreeNode(OFTrue),
+    EmptyNumericMeasurement()
+{
+    if (item.TreeNode != NULL)
+        TreeNode = item.TreeNode->clone();
+}
+
+
 DSRContentItem::~DSRContentItem()
 {
+    if (DeleteTreeNode)
+        delete TreeNode;
 }
 
 
@@ -613,6 +626,33 @@ OFCondition DSRContentItem::setContinuityOfContent(const E_ContinuityOfContent c
 }
 
 
+OFCondition DSRContentItem::getTemplateIdentification(OFString &templateIdentifier,
+                                                      OFString &mappingResource) const
+{
+    OFCondition result = EC_IllegalCall;
+    if (TreeNode != NULL)
+    {
+        if (TreeNode->getValueType() == VT_Container)
+            result = TreeNode->getTemplateIdentification(templateIdentifier, mappingResource);
+    }
+    return result;
+}
+
+
+OFCondition DSRContentItem::setTemplateIdentification(const OFString &templateIdentifier,
+                                                      const OFString &mappingResource,
+                                                      const OFBool check)
+{
+    OFCondition result = EC_IllegalCall;
+    if (TreeNode != NULL)
+    {
+        if (TreeNode->getValueType() == VT_Container)
+            result = TreeNode->setTemplateIdentification(templateIdentifier, mappingResource, check);
+    }
+    return result;
+}
+
+
 DSRCodedEntryValue *DSRContentItem::getConceptNamePtr()
 {
     DSRCodedEntryValue *pointer = NULL;
@@ -685,24 +725,3 @@ OFCondition DSRContentItem::setObservationUID(const OFString &observationUID,
         result = TreeNode->setObservationUID(observationUID, check);
     return result;
 }
-
-
-OFCondition DSRContentItem::getTemplateIdentification(OFString &templateIdentifier,
-                                                      OFString &mappingResource) const
-{
-    OFCondition result = EC_IllegalCall;
-    if (TreeNode != NULL)
-        result = TreeNode->getTemplateIdentification(templateIdentifier, mappingResource);
-    return result;
-}
-
-
-OFCondition DSRContentItem::setTemplateIdentification(const OFString &templateIdentifier,
-                                                      const OFString &mappingResource,
-                                                      const OFBool check)
-{
-    OFCondition result = EC_IllegalCall;
-    if (TreeNode != NULL)
-        result = TreeNode->setTemplateIdentification(templateIdentifier, mappingResource, check);
-    return result;
-}
