@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2013, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRCompositeTreeNode
@@ -37,11 +37,24 @@ DSRCompositeTreeNode::DSRCompositeTreeNode(const E_RelationshipType relationship
 }
 
 
+DSRCompositeTreeNode::DSRCompositeTreeNode(const DSRCompositeTreeNode &node)
+  : DSRDocumentTreeNode(node),
+    DSRCompositeReferenceValue(node)
+{
+}
+
+
 DSRCompositeTreeNode::~DSRCompositeTreeNode()
 {
 }
 
 
+DSRCompositeTreeNode *DSRCompositeTreeNode::clone() const
+{
+    return new DSRCompositeTreeNode(*this);
+}
+
+
 void DSRCompositeTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
