@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRContainerTreeNode
@@ -30,8 +30,15 @@
 
 DSRContainerTreeNode::DSRContainerTreeNode(const E_RelationshipType relationshipType,
                                            const E_ContinuityOfContent continuityOfContent)
- : DSRDocumentTreeNode(relationshipType, VT_Container),
-   ContinuityOfContent(continuityOfContent)
+  : DSRDocumentTreeNode(relationshipType, VT_Container),
+    ContinuityOfContent(continuityOfContent)
+{
+}
+
+
+DSRContainerTreeNode::DSRContainerTreeNode(const DSRContainerTreeNode &node)
+  : DSRDocumentTreeNode(node),
+    ContinuityOfContent(node.ContinuityOfContent)
 {
 }
 
@@ -41,6 +48,12 @@ DSRContainerTreeNode::~DSRContainerTreeNode()
 }
 
 
+DSRContainerTreeNode *DSRContainerTreeNode::clone() const
+{
+    return new DSRContainerTreeNode(*this);
+}
+
+
 void DSRContainerTreeNode::clear()
 {
     ContinuityOfContent = COC_Separate;      // this is more useful that COC_invalid
