@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2015, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -72,14 +72,6 @@ DSRDocumentSubTree::~DSRDocumentSubTree()
 }
 
 
-DSRDocumentSubTree &DSRDocumentSubTree::operator=(DSRDocumentSubTree tree)
-{
-    /* by-value parameter serves as a temporary */
-    swap(tree);
-    return *this;
-}
-
-
 DSRDocumentSubTree *DSRDocumentSubTree::clone() const
 {
     return new DSRDocumentSubTree(*this);
@@ -119,33 +111,6 @@ OFBool DSRDocumentSubTree::isValidDocumentTree(const E_RelationshipType defaultR
 }
 
 
-OFBool DSRDocumentSubTree::hasTemplateIdentification() const
-{
-    OFBool result = OFFalse;
-    /* check whether template identification is possible */
-    if (canUseTemplateIdentification())
-    {
-        /* check whether template identification is set */
-        result = getRoot()->hasTemplateIdentification();
-    }
-    return result;
-}
-
-
-OFBool DSRDocumentSubTree::canUseTemplateIdentification() const
-{
-    OFBool result = OFFalse;
-    /* check root node */
-    const DSRDocumentTreeNode *node = getRoot();
-    if (node != NULL)
-    {
-        /* make sure that there is a single root node only, with type "CONTAINER" */
-        result = (node->getValueType() == VT_Container) && !node->hasSiblingNodes();
-    }
-    return result;
-}
-
-
 OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
                                       const size_t flags)
 {
@@ -155,8 +120,6 @@ OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
     {
         /* check and update by-reference relationships (if applicable) */
         checkByReferenceRelationships(CM_updatePositionString);
-        /* update the document tree for output (if needed) */
-        updateTreeForOutput();
         OFString tmpString;
         size_t level = 0;
         const DSRDocumentTreeNode *node = NULL;
@@ -165,9 +128,6 @@ OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
             node = cursor.getNode();
             if (node != NULL)
             {
-                /* print node ID (might be useful for debugging purposes) */
-                if (flags & PF_printNodeID)
-                    stream << "id:" << node->getNodeID() << " ";
                 /* print node position */
                 if (flags & PF_printItemPosition)
                 {
@@ -190,28 +150,19 @@ OFCondition DSRDocumentSubTree::print(STD_NAMESPACE ostream &stream,
                 {
                     stream << " {" << dicomToReadableDateTime(node->getObservationDateTime(), tmpString) << "}";
                 }
-                /* print annotation (optional) */
-                if (node->hasAnnotation() && (flags & PF_printAnnotation))
+                if (flags & PF_printTemplateIdentification)
                 {
-                    DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_ANNOTATION)
-                    stream << "  \"" << node->getAnnotation().getText() << "\"";
-                }
-                /* print template identification (conditional) */
-                if (node->hasTemplateIdentification() && (flags & PF_printTemplateIdentification))
-                {
-                    OFString templateIdentifier;
-                    OFString mappingResource;
-                    OFString mappingResourceUID;
-                    if (node->getTemplateIdentification(templateIdentifier, mappingResource, mappingResourceUID).good())
+                    /* check for template identification */
+                    OFString templateIdentifier, mappingResource;
+                    if (node->getTemplateIdentification(templateIdentifier, mappingResource).good())
                     {
-                        DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_DELIMITER)
-                        stream << "  # ";
-                        DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_TEMPLATE_ID)
-                        stream << "TID " << templateIdentifier;
-                        stream << " (" << mappingResource;
-                        if (!mappingResourceUID.empty())
-                            stream << ", " << mappingResourceUID;
-                        stream << ")";
+                        if (!templateIdentifier.empty() && !mappingResource.empty())
+                        {
+                            DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_DELIMITER)
+                            stream << "  # ";
+                            DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_TEMPLATE_ID)
+                            stream << "TID " << templateIdentifier << " (" << mappingResource << ")";
+                        }
                     }
                 }
                 DCMSR_PRINT_ANSI_ESCAPE_CODE(DCMSR_ANSI_ESCAPE_CODE_RESET)
@@ -263,24 +214,6 @@ size_t DSRDocumentSubTree::gotoNextNamedNode(const DSRCodedEntryValue &conceptNa
 }
 
 
-size_t DSRDocumentSubTree::gotoAnnotatedNode(const OFString &annotationText,
-                                             const OFBool startFromRoot)
-{
-    /* call the inherited function */
-    return gotoNode(DSRTreeNodeAnnotation(annotationText), startFromRoot);
-}
-
-
-size_t DSRDocumentSubTree::gotoNextAnnotatedNode(const OFString &annotationText)
-{
-    /* first, goto "next" node */
-    size_t nodeID = iterate();
-    if (nodeID > 0)
-        nodeID = gotoAnnotatedNode(annotationText, OFFalse /*startFromRoot*/);
-    return nodeID;
-}
-
-
 OFBool DSRDocumentSubTree::canAddContentItem(const E_RelationshipType relationshipType,
                                              const E_ValueType valueType,
                                              const E_AddMode addMode)
@@ -401,12 +334,9 @@ OFCondition DSRDocumentSubTree::addContentItem(const E_RelationshipType relation
     /* call the functions doing the real work */
     if (addContentItem(relationshipType, valueType, AM_afterCurrent) > 0)
     {
-        if (!conceptName.isEmpty())
-        {
-            /* use a more appropriate error code than the one returned */
-            if (getCurrentContentItem().setConceptName(conceptName).bad())
-                result = SR_EC_InvalidConceptName;
-        }
+        /* use a more appropriate error code than the one returned */
+        if (getCurrentContentItem().setConceptName(conceptName).bad())
+            result = SR_EC_InvalidConceptName;
     } else
         result = SR_EC_CannotAddContentItem;
     return result;
@@ -421,12 +351,9 @@ OFCondition DSRDocumentSubTree::addChildContentItem(const E_RelationshipType rel
     /* call the functions doing the real work */
     if (addContentItem(relationshipType, valueType, AM_belowCurrent) > 0)
     {
-        if (!conceptName.isEmpty())
-        {
-            /* use a more appropriate error code than the one returned */
-            if (getCurrentContentItem().setConceptName(conceptName).bad())
-                result = SR_EC_InvalidConceptName;
-        }
+        /* use a more appropriate error code than the one returned */
+        if (getCurrentContentItem().setConceptName(conceptName).bad())
+            result = SR_EC_InvalidConceptName;
     } else
         result = SR_EC_CannotAddContentItem;
     return result;
@@ -634,63 +561,8 @@ DSRDocumentSubTree *DSRDocumentSubTree::cloneSubTree(const size_t stopAfterNodeI
 }
 
 
-OFCondition DSRDocumentSubTree::getTemplateIdentification(OFString &templateIdentifier,
-                                                          OFString &mappingResource) const
-{
-    OFCondition result = SR_EC_CannotUseTemplateIdentification;
-    /* check whether template identification is possible */
-    if (canUseTemplateIdentification())
-    {
-        /* get template identification from root CONTAINER */
-        result = getRoot()->getTemplateIdentification(templateIdentifier, mappingResource);
-    }
-    return result;
-}
-
-
-OFCondition DSRDocumentSubTree::getTemplateIdentification(OFString &templateIdentifier,
-                                                          OFString &mappingResource,
-                                                          OFString &mappingResourceUID) const
-{
-    OFCondition result = SR_EC_CannotUseTemplateIdentification;
-    /* check whether template identification is possible */
-    if (canUseTemplateIdentification())
-    {
-        /* get template identification from root CONTAINER */
-        result = getRoot()->getTemplateIdentification(templateIdentifier, mappingResource, mappingResourceUID);
-    }
-    return result;
-}
-
-
-OFCondition DSRDocumentSubTree::setTemplateIdentification(const OFString &templateIdentifier,
-                                                          const OFString &mappingResource,
-                                                          const OFString &mappingResourceUID,
-                                                          const OFBool check)
-{
-    OFCondition result = SR_EC_CannotUseTemplateIdentification;
-    /* check whether template identification is possible */
-    if (canUseTemplateIdentification())
-    {
-        /* mark root CONTAINER with given template identification */
-        result = getRoot()->setTemplateIdentification(templateIdentifier, mappingResource, mappingResourceUID, check);
-    }
-    return result;
-}
-
-
 // protected methods
 
-void DSRDocumentSubTree::swap(DSRDocumentSubTree &tree)
-{
-    /* call inherited method */
-    DSRTree<DSRDocumentTreeNode>::swap(tree);
-    /* swap other members */
-    CurrentContentItem.swap(tree.CurrentContentItem);
-    OFswap(ConstraintChecker, tree.ConstraintChecker);
-}
-
-
 size_t DSRDocumentSubTree::addNode(DSRDocumentTreeNode *node,
                                    const E_AddMode addMode)
 {
@@ -706,13 +578,6 @@ DSRDocumentTreeNode *DSRDocumentSubTree::extractNode()
 }
 
 
-DSRDocumentTreeNode *DSRDocumentSubTree::getAndRemoveRootNode()
-{
-    /* might add further checks later on */
-    return DSRTree<DSRDocumentTreeNode>::getAndRemoveRootNode();
-}
-
-
 size_t DSRDocumentSubTree::removeNode()
 {
     /* might add further checks later on */
@@ -852,12 +717,6 @@ void DSRDocumentSubTree::resetReferenceTargetFlag()
 }
 
 
-void DSRDocumentSubTree::updateTreeForOutput()
-{
-    /* nothing to do for this class, might be overwritten in derived classes */
-}
-
-
 OFCondition DSRDocumentSubTree::checkSubTreeConstraints(DSRDocumentSubTree *tree,
                                                         DSRIODConstraintChecker *checker)
 {
