@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2013, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRDocumentTreeNode
@@ -50,6 +50,23 @@ DSRDocumentTreeNode::DSRDocumentTreeNode(const E_RelationshipType relationshipTy
 }
 
 
+DSRDocumentTreeNode::DSRDocumentTreeNode(const DSRDocumentTreeNode &node)
+  : DSRTreeNode(),
+    MarkFlag(node.MarkFlag),
+    ReferenceTarget(OFFalse),
+    RelationshipType(node.RelationshipType),
+    ValueType(node.ValueType),
+    ConceptName(node.ConceptName),
+    ObservationDateTime(node.ObservationDateTime),
+    ObservationUID(node.ObservationUID),
+    TemplateIdentifier(node.TemplateIdentifier),
+    MappingResource(node.MappingResource),
+    MACParameters(DCM_MACParametersSequence),
+    DigitalSignatures(DCM_DigitalSignaturesSequence)
+{
+}
+
+
 DSRDocumentTreeNode::~DSRDocumentTreeNode()
 {
 }
@@ -133,10 +150,10 @@ OFCondition DSRDocumentTreeNode::readXML(const DSRXMLDocument &doc,
         DSRDocumentTreeNode *node = NULL;
         /* read "id" attribute (optional) and compare with expected value */
         if (!doc.getStringFromAttribute(cursor, idAttr, "id", OFFalse /*encoding*/, OFFalse /*required*/).empty() &&
-            (stringToNumber(idAttr.c_str()) != Ident))
+            (stringToNumber(idAttr.c_str()) != getNodeID()))
         {
             /* create warning message */
-            DCMSR_WARN("XML attribute 'id' (" << idAttr << ") deviates from current node number (" << Ident << ")");
+            DCMSR_WARN("XML attribute 'id' (" << idAttr << ") deviates from current node number (" << getNodeID() << ")");
         }
         /* template identification information expected "inside" content item */
         if (!(flags & XF_templateElementEnclosesItems))
@@ -285,12 +302,13 @@ OFCondition DSRDocumentTreeNode::writeXML(STD_NAMESPACE ostream &stream,
         stream << "</observation>" << OFendl;
     }
     /* write child nodes (if any) */
-    DSRTreeNodeCursor cursor(Down);
+    DSRDocumentTreeNodeCursor cursor(getDown());
     if (cursor.isValid())
     {
-        DSRDocumentTreeNode *node = NULL;
-        do {    /* for all child nodes */
-            node = OFstatic_cast(DSRDocumentTreeNode *, cursor.getNode());
+        const DSRDocumentTreeNode *node = NULL;
+        /* for all child nodes */
+        do {
+            node = cursor.getNode();
             if (node != NULL)
                 result = node->writeXML(stream, flags);
             else
@@ -372,6 +390,23 @@ OFCondition DSRDocumentTreeNode::renderHTML(STD_NAMESPACE ostream &docStream,
 }
 
 
+OFCondition DSRDocumentTreeNode::setRelationshipType(const E_RelationshipType relationshipType)
+{
+    OFCondition result = EC_Normal;
+    /* check parameter before setting the value */
+    if ((relationshipType != RT_invalid) && (relationshipType != RT_unknown) && (relationshipType != RT_isRoot))
+    {
+        /* only "unknown" relationship types can be replaced */
+        if (RelationshipType == RT_unknown)
+            RelationshipType = relationshipType;
+        else
+            result = SR_EC_CannotChangeRelationshipType;
+    } else
+        result = EC_IllegalParameter;
+    return result;
+}
+
+
 OFCondition DSRDocumentTreeNode::getConceptName(DSRCodedEntryValue &conceptName) const
 {
     conceptName = ConceptName;
@@ -444,6 +479,9 @@ OFCondition DSRDocumentTreeNode::setTemplateIdentification(const OFString &templ
     }
     if (result.good())
     {
+        if ((ValueType != VT_Container) && !templateIdentifier.empty())
+            DCMSR_WARN("Template identification should only be specified for CONTAINER content items");
+        /* set current values, might be empty */
         TemplateIdentifier = templateIdentifier;
         MappingResource = mappingResource;
     }
@@ -532,6 +570,8 @@ OFCondition DSRDocumentTreeNode::readDocumentRelationshipMacro(DcmItem &dataset,
     DcmItem *ditem = NULL;
     if (dataset.findAndGetSequenceItem(DCM_ContentTemplateSequence, ditem, 0 /*itemNum*/).good())
     {
+        if (ValueType != VT_Container)
+            DCMSR_WARN("Found ContentTemplateSequence for content item that is not a CONTAINER");
         getAndCheckStringValueFromDataset(*ditem, DCM_MappingResource, MappingResource, "1", "1", "ContentTemplateSequence");
         getAndCheckStringValueFromDataset(*ditem, DCM_TemplateIdentifier, TemplateIdentifier, "1", "1", "ContentTemplateSequence");
         /* check for a common error: Template Identifier includes "TID" prefix */
@@ -602,6 +642,8 @@ OFCondition DSRDocumentTreeNode::writeDocumentRelationshipMacro(DcmItem &dataset
             result = dataset.findOrCreateSequenceItem(DCM_ContentTemplateSequence, ditem, 0 /*position*/);
             if (result.good())
             {
+                if (ValueType != VT_Container)
+                    DCMSR_WARN("Writing ContentTemplateSequence for content item that is not a CONTAINER");
                 /* write item data */
                 putStringValueToDataset(*ditem, DCM_TemplateIdentifier, TemplateIdentifier);
                 putStringValueToDataset(*ditem, DCM_MappingResource, MappingResource);
@@ -849,7 +891,7 @@ OFCondition DSRDocumentTreeNode::writeContentSequence(DcmItem &dataset,
 {
     OFCondition result = EC_Normal;
     /* goto first child of current node */
-    DSRTreeNodeCursor cursor(Down);
+    DSRDocumentTreeNodeCursor cursor(getDown());
     if (cursor.isValid())
     {
         /* write ContentSequence */
@@ -858,8 +900,9 @@ OFCondition DSRDocumentTreeNode::writeContentSequence(DcmItem &dataset,
         {
             DcmItem *ditem = NULL;
             DSRDocumentTreeNode *node = NULL;
-            do {        /* for all child nodes */
-                node = OFstatic_cast(DSRDocumentTreeNode *, cursor.getNode());
+            /* for all child nodes */
+            do {
+                node = cursor.getNode();
                 if (node != NULL)
                 {
                     ditem = new DcmItem();
@@ -962,7 +1005,7 @@ OFCondition DSRDocumentTreeNode::renderHTMLChildNodes(STD_NAMESPACE ostream &doc
 {
     OFCondition result = EC_Normal;
     /* goto first child of current node */
-    DSRTreeNodeCursor cursor(Down);
+    DSRDocumentTreeNodeCursor cursor(getDown());
     if (cursor.isValid())
     {
         /* flag used to format the relationship reference texts */
@@ -973,9 +1016,10 @@ OFCondition DSRDocumentTreeNode::renderHTMLChildNodes(STD_NAMESPACE ostream &doc
         size_t footnoteNumber = 1;
         /* create memory output stream for the temporal document */
         OFOStringStream tempDocStream;
-        DSRDocumentTreeNode *node = NULL;
-        do {        /* for all child nodes */
-            node = OFstatic_cast(DSRDocumentTreeNode *, cursor.getNode());
+        const DSRDocumentTreeNode *node = NULL;
+        /* for all child nodes */
+        do {
+            node = cursor.getNode();
             if (node != NULL)
             {
                 /* set/reset flag for footnote creation*/
@@ -1130,6 +1174,8 @@ OFCondition DSRDocumentTreeNode::renderHTMLChildNodes(STD_NAMESPACE ostream &doc
 }
 
 
+// static functions
+
 const OFString &DSRDocumentTreeNode::getRelationshipText(const E_RelationshipType relationshipType,
                                                          OFString &relationshipText,
                                                          const size_t flags)
