@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2013, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRPNameTreeNode
@@ -44,11 +44,24 @@ DSRPNameTreeNode::DSRPNameTreeNode(const E_RelationshipType relationshipType,
 }
 
 
+DSRPNameTreeNode::DSRPNameTreeNode(const DSRPNameTreeNode &node)
+  : DSRDocumentTreeNode(node),
+    DSRStringValue(node)
+{
+}
+
+
 DSRPNameTreeNode::~DSRPNameTreeNode()
 {
 }
 
 
+DSRPNameTreeNode *DSRPNameTreeNode::clone() const
+{
+    return new DSRPNameTreeNode(*this);
+}
+
+
 void DSRPNameTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
