@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRByReferenceTreeNode
@@ -29,20 +29,33 @@
 
 
 DSRByReferenceTreeNode::DSRByReferenceTreeNode(const E_RelationshipType relationshipType)
- : DSRDocumentTreeNode(relationshipType, VT_byReference),
-   ValidReference(OFFalse),
-   ReferencedContentItem(),
-   ReferencedNodeID(0)
+  : DSRDocumentTreeNode(relationshipType, VT_byReference),
+    ValidReference(OFFalse),
+    ReferencedContentItem(),
+    ReferencedNodeID(0),
+    TargetValueType(VT_invalid)
 {
 }
 
 
 DSRByReferenceTreeNode::DSRByReferenceTreeNode(const E_RelationshipType relationshipType,
-                                               const size_t referencedNodeID)
- : DSRDocumentTreeNode(relationshipType, VT_byReference),
-   ValidReference(OFFalse),
-   ReferencedContentItem(),
-   ReferencedNodeID(referencedNodeID)
+                                               const size_t referencedNodeID,
+                                               const E_ValueType targetValueType)
+  : DSRDocumentTreeNode(relationshipType, VT_byReference),
+    ValidReference(OFFalse),
+    ReferencedContentItem(),
+    ReferencedNodeID(referencedNodeID),
+    TargetValueType(targetValueType)
+{
+}
+
+
+DSRByReferenceTreeNode::DSRByReferenceTreeNode(const DSRByReferenceTreeNode &node)
+  : DSRDocumentTreeNode(node),
+    ValidReference(OFFalse),
+    ReferencedContentItem(node.ReferencedContentItem),
+    ReferencedNodeID(0),
+    TargetValueType(VT_invalid)
 {
 }
 
@@ -52,12 +65,19 @@ DSRByReferenceTreeNode::~DSRByReferenceTreeNode()
 }
 
 
+DSRByReferenceTreeNode *DSRByReferenceTreeNode::clone() const
+{
+    return new DSRByReferenceTreeNode(*this);
+}
+
+
 void DSRByReferenceTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
     ValidReference = OFFalse;
     ReferencedContentItem.clear();
     ReferencedNodeID = 0;
+    TargetValueType = VT_invalid;
 }
 
 
@@ -97,7 +117,7 @@ OFCondition DSRByReferenceTreeNode::readContentItem(DcmItem &dataset)
     DcmUnsignedLong delem(DCM_ReferencedContentItemIdentifier);
     /* clear before reading */
     ReferencedContentItem.clear();
-    ReferencedNodeID = 0;
+    updateReference(0, VT_invalid);
     /* read ReferencedContentItemIdentifier */
     OFCondition result = getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", "by-reference relationship");
     if (result.good())
@@ -212,3 +232,30 @@ OFCondition DSRByReferenceTreeNode::setTemplateIdentification(const OFString & /
     /* invalid: no template identification allowed */
     return EC_IllegalCall;
 }
+
+
+void DSRByReferenceTreeNode::invalidateReference()
+{
+    ValidReference = OFFalse;
+}
+
+
+OFBool DSRByReferenceTreeNode::updateReference(const size_t referencedNodeID,
+                                               const E_ValueType targetValueType)
+{
+    ReferencedNodeID = referencedNodeID;
+    TargetValueType = targetValueType;
+    /* check whether the given reference is valid */
+    ValidReference = (ReferencedNodeID > 0);
+    return ValidReference;
+}
+
+
+OFBool DSRByReferenceTreeNode::updateReference(const OFString &referencedContentItem)
+{
+
+    ReferencedContentItem = referencedContentItem;
+    /* tbd: check for valid reference could be more strict */
+    ValidReference = checkForValidReference(ReferencedContentItem);
+    return ValidReference;
+}
