@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRTimeTreeNode
@@ -44,11 +44,24 @@ DSRTimeTreeNode::DSRTimeTreeNode(const E_RelationshipType relationshipType,
 }
 
 
+DSRTimeTreeNode::DSRTimeTreeNode(const DSRTimeTreeNode &node)
+  : DSRDocumentTreeNode(node),
+    DSRStringValue(node)
+{
+}
+
+
 DSRTimeTreeNode::~DSRTimeTreeNode()
 {
 }
 
 
+DSRTimeTreeNode *DSRTimeTreeNode::clone() const
+{
+    return new DSRTimeTreeNode(*this);
+}
+
+
 void DSRTimeTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
