@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRTypes
@@ -267,6 +267,14 @@ makeOFConditionConst(SR_EC_CodingSchemeNotFound,             OFM_dcmsr, 13, OF_e
 makeOFConditionConst(SR_EC_CorruptedXMLStructure,            OFM_dcmsr, 14, OF_error, "Corrupted XML structure");
 makeOFConditionConst(SR_EC_RepresentationNotAvailable,       OFM_dcmsr, 15, OF_error, "Representation not available");
 makeOFConditionConst(SR_EC_CannotCreateIconImage,            OFM_dcmsr, 16, OF_error, "Cannot create Icon Image");
+makeOFConditionConst(SR_EC_CannotAddContentItem,             OFM_dcmsr, 17, OF_error, "Cannot add Content Item");
+makeOFConditionConst(SR_EC_InvalidConceptName,               OFM_dcmsr, 18, OF_error, "Invalid Concept Name");
+makeOFConditionConst(SR_EC_CannotInsertSubTree,              OFM_dcmsr, 19, OF_error, "Cannot insert Subtree");
+makeOFConditionConst(SR_EC_CannotChangeRelationshipType,     OFM_dcmsr, 20, OF_error, "Cannot change Relationship Type");
+makeOFConditionConst(SR_EC_IncompatibleDocumentTree,         OFM_dcmsr, 21, OF_error, "Incompatible Document Tree");
+makeOFConditionConst(SR_EC_ContentItemNotFound,              OFM_dcmsr, 22, OF_error, "Content Item not found");
+makeOFConditionConst(SR_EC_CannotRemoveSubTree,              OFM_dcmsr, 23, OF_error, "Cannot remove Subtree");
+makeOFConditionConst(SR_EC_EmptyDocumentTree,                OFM_dcmsr, 24, OF_error, "Empty Document Tree");
 
 
 static const S_DocumentTypeNameMap DocumentTypeNameMap[] =
