@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2012, OFFIS e.V.
+ *  Copyright (C) 2000-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -11,9 +11,9 @@
  *    D-26121 Oldenburg, Germany
  *
  *
- *  Module:  dcmsr
+ *  Module: dcmsr
  *
- *  Author:  Joerg Riesmeier
+ *  Author: Joerg Riesmeier
  *
  *  Purpose:
  *    classes: DSRUIDRefTreeNode
@@ -44,11 +44,24 @@ DSRUIDRefTreeNode::DSRUIDRefTreeNode(const E_RelationshipType relationshipType,
 }
 
 
+DSRUIDRefTreeNode::DSRUIDRefTreeNode(const DSRUIDRefTreeNode &node)
+  : DSRDocumentTreeNode(node),
+    DSRStringValue(node)
+{
+}
+
+
 DSRUIDRefTreeNode::~DSRUIDRefTreeNode()
 {
 }
 
 
+DSRUIDRefTreeNode *DSRUIDRefTreeNode::clone() const
+{
+    return new DSRUIDRefTreeNode(*this);
+}
+
+
 void DSRUIDRefTreeNode::clear()
 {
     DSRDocumentTreeNode::clear();
