@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2000-2013, OFFIS e.V.
+ *  Copyright (C) 2000-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -337,6 +337,26 @@ DcmTransportLayerStatus DcmTLSTransportLayer::addTrustedCertificateDir(const cha
   return TCS_ok;
 }
 
+DcmTransportLayerStatus DcmTLSTransportLayer::addTrustedClientCertificateFile(const char *fileName)
+{
+  if (transportLayerContext)
+  {
+    STACK_OF(X509_NAME) *caNames = sk_X509_NAME_dup(SSL_CTX_get_client_CA_list(transportLayerContext));
+    if (caNames == NULL)
+      caNames = sk_X509_NAME_new_null();
+    STACK_OF(X509_NAME) *newCaNames = SSL_load_client_CA_file(fileName);
+    for (int i = 0; i < sk_X509_NAME_num(newCaNames); ++i)
+    {
+      X509_NAME *newCaName = sk_X509_NAME_value(newCaNames,i);
+      if (sk_X509_NAME_find(caNames,newCaName) == -1)
+        sk_X509_NAME_push(caNames,X509_NAME_dup(newCaName));
+    }
+    sk_X509_NAME_pop_free(newCaNames,X509_NAME_free);
+    SSL_CTX_set_client_CA_list(transportLayerContext,caNames);
+  } else return TCS_illegalCall;
+  return TCS_ok;
+}
+
 DcmTransportConnection *DcmTLSTransportLayer::createConnection(int openSocket, OFBool useSecureLayer)
 {
   if (useSecureLayer)
