@@ -29,6 +29,7 @@
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofdefine.h"
 #include "dcmtk/ofstd/oftraits.h"
+#include "dcmtk/ofstd/ofalign.h"
 
 // include <type_traits> for "std::is_default_constructible"
 // to recover from compiler insanity (Visual Studio 12+).
@@ -81,6 +82,210 @@ unspecified OFnullopt_t;
 OFnullpt_t OFnullopt;
 #endif // DOXYGEN
 
+/** Default storage traits of OFoptional<T>.
+ *  OFdefault_optional_traits manages the state and storage of the contained
+ *  object in a portable manner. You may use this class as base when defining
+ *  custom traits for a specific type T, so you won't have to re-implement
+ *  this functionality entirely.
+ *  @relates OFoptional
+ *  @tparam T the content type of the respective OFoptional instance.
+ *  @sa OFoptional
+ *  @sa OFoptional_traits
+ *  @details
+ *  <h2>@anchor ofoptional_trait_override Example</h2>
+ *  This example shows how to override the <i>is_default_constructible</i>
+ *  attribute of <kbd>OFoptional_traits</kbd> for the custom class <i>Test</i>.
+ *  @code
+ *  // Note: Test's default constructor is private
+ *  //   which leads to errors when being used within
+ *  //   OFoptional, since a default constructor exists
+ *  //   but can't be accessed.
+ *  class Test
+ *  {
+ *      Test() {}
+ *  public:
+ *      static OFoptional<T> instance();
+ *           .
+ *           .
+ *           .
+ *  };
+ *
+ *  // Override OFoptional's behavior to fix this problem
+ *  template<>
+ *  struct OFoptional_traits<Test>
+ *  : OFdefault_optional_traits<Test> // derived from default traits
+ *  {
+ *      // Tell OFoptional that it can't default-construct
+ *      // a Test object.
+ *      typedef OFfalse_type is_default_constructible;
+ *  };
+ *  @endcode
+ */
+template<typename T>
+class OFdefault_optional_traits
+{
+#ifndef DOXYGEN
+    // types for detecting T's default constructibility via sfinae
+    struct no_type {};
+    struct yes_type {double d;};
+#ifndef _MSC_VER
+    // helper class to create an argument out of size_t
+    template<size_t>
+    struct consume{};
+    // sfinae overload working for default constructible Xs
+    template<typename X>
+    static yes_type sfinae(consume<sizeof *new X>*);
+#elif _MSC_VER < 1700
+    // Workaround bug in Visual Studio.
+    // On these broken compilers, the argument is not evaluated
+    // unless we require them to evaluate it for choosing which
+    // specialization should be instantiated.
+    template<size_t,size_t>
+    struct consume{};
+    template<size_t X>
+    struct consume<X,X> { typedef void type; };
+    // sfinae overload working for value-initializable Xs, that's as
+    // close as we get on these broken compilers
+    template<typename X>
+    static yes_type sfinae(typename consume<sizeof X(),sizeof X()>::type*);
+#else
+    // Visual Stuio 2012 is completely broken, but it has std::is_defaul_constructible
+    // Note: this tests constructibility, but not if WE can construct this.
+    template<typename X>
+    static yes_type sfinae(typename OFenable_if<std::is_default_constructible<X>::value>::type*);
+#endif
+    // most general sfinae overload, chosen only if everything else fails
+    template<typename X>
+    static no_type sfinae(...);
+
+public:
+    struct is_default_constructible
+    : OFintegral_constant<OFBool,sizeof(sfinae<T>(OFnullptr)) == sizeof(yes_type)> {};
+
+#ifdef DCMTK_USE_CXX11_STL
+
+    template<typename... Args>
+    void construct( Args&&... args )
+    { new (content()) T( std::forward<Args>( args )... ); m_State = OFTrue; }
+
+#else // C++11
+
+#ifdef OFalign
+    void construct() { new (content()) T; m_State = OFTrue; }
+    template<typename X>
+    void construct( const X& x ) { new (content()) T( x ); m_State = OFTrue; }
+#else
+    void construct() { m_pContent = new T; }
+    template<typename X>
+    void construct( const X& x ) { m_pContent = new T( x ); }
+#endif
+
+#endif // NOT C++11
+
+#ifdef OFalign
+    // State and content are stored in the same data-array to
+    // optimize alignment and so on. Mutable, since the content
+    // itself can be modified even if it cant be (re-)assigned.
+    OFdefault_optional_traits() : m_State( OFFalse ) {}
+    void destroy() { OFstatic_cast( T*, content() )->~T(); m_State = OFFalse; }
+    OFBool state() const { return m_State; }
+    void* content() const { return m_Content; }
+    mutable OFalign_typename(Uint8[sizeof(T)],T) m_Content;
+    OFBool m_State;
+#else
+    // Allocate content on the heap.
+    OFdefault_optional_traits() : m_pContent( OFnullptr ) {}
+    void destroy() { delete m_pContent; m_pContent = OFnullptr; }
+    OFBool state() const { return m_pContent; }
+    void* content() const { return m_pContent; }
+    T* m_pContent;
+#endif
+
+#endif // NOT DOXYGEN
+};
+
+/** Manages storage and state of the object contained in OFoptional<T>.
+ *  OFoptional_traits is a customization point for OFoptional that enables you to define a custom storage management policy for
+ *  individual types T. If you don't want to implement everything from scratch, use OFdefault_optional_traits as base class for
+ *  your implementation.
+ *  @relates OFoptional
+ *  @tparam the content type of the respective OFoptional instance.
+ *  @sa OFoptional
+ *  @sa OFdefault_optional_traits
+ *  @details
+ *  <h2>Example</h2>
+ *  The following example shows how to implement custom OFoptional_traits for an enum that already contains a specific element
+ *  to denote an invalid state.
+ *  @code
+ *  enum FILE_ACCESS
+ *  {
+ *    NONE  = 0000,
+ *    READ  = 0400,
+ *    WRITE = 0200,
+ *        . . .
+ *    INVALID_ACCESS_CODE = 01000
+ *  };
+ *
+ *  template<>
+ *  struct OFoptional_traits<FILE_ACCESS>
+ *  {
+ *    // Tell OFoptional that this is default-constructible
+ *    typedef OFtrue_type is_default_constructible;
+ *    // Initialize storage to the invalid state during construction
+ *    OFoptional_traits() : access( INVALID_ACCESS_CODE ) {}
+ *    // Constructors
+ *    void construct()                 { access = NONE; }
+ *    void construct( FILE_ACCESS fa ) { access = fa; }
+ *    // There is nothing to destroy, just set the state to "disengaged"
+ *    void destroy()                   { access = INVALID_ACCESS_CODE; }
+ *    // Tell OFoptional how to distinguish "engaged" and "disengaged" FILE_ACCESS objects
+ *    OFBool state() const             { return access != INVALID_ACCESS_CODE; }
+ *    // Just return a pointer to the underlying object
+ *    void* content() const            { return &access; }
+ *    // The actual object
+ *    mutable FILE_ACCESS access;
+ *  };
+ *
+ *  COUT << "This should now be the same: " << sizeof( FILE_ACCESS ) << ' ' << sizeof( OFoptional<FILE_ACCESS> ) << OFendl;
+ *  @endcode
+ */
+template<typename T>
+struct OFoptional_traits
+#ifndef DOXYGEN
+: OFdefault_optional_traits<T>
+#endif
+{
+#ifdef DOXYGEN
+    /** <b>Required</b>: default construction policy.
+     *  You need to define an appropriate integral constant as "is_default_constructible"
+     *  that denotes if OFoptional<T> may attempt to default construct the underlying object
+     *  under certain circumstances. You may use <kbd>OFdefault_optional_traits<T>::is_default_constructible</kbd>
+     *  to specify this member, which uses SFINAE mechanisms to query a type's default constructibility.
+     */
+    <unspecified> is_default_constructible;
+
+    /// <b>Requried</b>: default constructor, must initialize the state to "disengaged".
+    OFoptional_traits();
+
+    /** <b>Required</b>: type constructors, construct the contained object.
+     *  You need to define at least one method of this kind, that takes appropriate
+     *  parameter(s) to construct the underlying object. Must set the state to "engaged".
+     *  If <kbd>is_default_constructible</kbd> evaluates to <i>OFTrue</i>, an overload
+     *  taking zero arguments is also required.
+     */
+    void construct(...);
+
+    /// <b>Required</b>: type destructor, destroys the underlying object and must set the state to "disengaged".
+    void destroy();
+
+    /// <b>Required</b>: state query, must return <i>OFTrue</i> when "engaged" and <i>OFFalse</i> otherwhise.
+    OFBool state() const;
+
+    /// <b>Required</b>: content access, must return a pointer to the contained object.
+    void* content() const;
+#endif
+};
+
 /** The class template OFoptional manages an optional contained value, i.e.\ a value tagged with a state that reports its validity.
  *  A common use case for OFoptional is the return value of a function that may fail. OFoptional handles expensive to construct
  *  objects well and is more readable, as the intent is expressed explicitly.
@@ -90,8 +295,10 @@ OFnullpt_t OFnullopt;
  *  @tparam T the type of the value to manage initialization state for. The type's destructor must be accessible by OFoptional<T>.
  *  @note There exists a sufficient specialization for reference types (T&) that behaves exactly like a pointer (T*) but allows
  *    OFoptional to be used in a generic context (when it's unknown if T is a reference or not).
+ *  @sa OFoptional_traits
+ *  @sa OFdefault_optional_traits
  *  @details
- *  ### @anchor optional_syntax %OFoptional Syntax ###
+ *  <h2>@anchor optional_syntax %OFoptional Syntax</h2>
  *  OFoptional can be used like a pointer to the contained value, except OFoptional also manages the contained value's storage.
  *  Several operators have been overloaded to simplify the usage of OFoptional. Instead of looking at every overload's specification,
  *  it is more appropriate to describe the possible syntax in a general manner. Therefore we declare the following symbols that are
@@ -147,7 +354,8 @@ OFnullpt_t OFnullopt;
  *        @note Detecting if T is default constructible within OFoptional<T> does not work correctly on all
  *          compilers. Especially all versions of Microsoft Visual Studio are impaired. For example a private
  *          default constructor of T might be detected as <i>not accessible</i> although OFoptional<T>
- *          was declared a friend of T.
+ *          was declared a friend of T. Specialize <kbd>OFoptional_traits</kbd> for a particular type T to
+ *          override constructibility detection as required. See @ref ofoptional_trait_override "this example".
  *      </td>
  *    </tr>
  *    <tr>
@@ -285,40 +493,11 @@ OFnullpt_t OFnullopt;
  */
 template<typename T>
 class OFoptional
+#ifndef DOXYGEN
+: OFoptional_traits<T>
+#endif
 {
 #ifndef DOXYGEN
-    // types for detecting T's default constructibility via sfinae
-    struct no_type {};
-    struct yes_type {double d;};
-#ifndef _MSC_VER
-    // helper class to create an argument out of size_t
-    template<size_t>
-    struct consume{};
-    // sfinae overload working for default constructible Xs
-    template<typename X>
-    static yes_type sfinae(consume<sizeof *new X>*);
-#elif _MSC_VER < 1700
-    // Workaround bug in Visual Studio.
-    // On these broken compilers, the argument is not evaluated
-    // unless we require them to evaluate it for choosing which
-    // specialization should be instantiated.
-    template<size_t,size_t>
-    struct consume{};
-    template<size_t X>
-    struct consume<X,X> { typedef void type; };
-    // sfinae overload working for value-initializable Xs, that's as
-    // close as we get on these broken compilers
-    template<typename X>
-    static yes_type sfinae(typename consume<sizeof X(),sizeof X()>::type*);
-#else
-    // Visual Stuio 2012 is completely broken, but it has std::is_defaul_constructible
-    // Note: this tests constructibility, but not if WE can construct this.
-    template<typename X>
-    static yes_type sfinae(typename OFenable_if<std::is_default_constructible<X>::value>::type*);
-#endif
-    // most general sfinae overload, chosen only if everything else fails
-    template<typename X>
-    static no_type sfinae(...);
     // create a matching istream type if condition is OFTrue
     template<typename Char,typename Traits,OFBool>
     struct if_istream{ typedef STD_NAMESPACE basic_istream<Char,Traits>& type; };
@@ -327,15 +506,9 @@ class OFoptional
     struct if_istream<Char,Traits,OFFalse> {};
     // use sfinae etc. to enable / disable the respective istream operator overloads
     template<typename Char,typename Traits>
-    struct if_constructible : if_istream<Char,Traits,sizeof(sfinae<T>(OFnullptr)) == sizeof(yes_type)> {};
+    struct if_constructible : if_istream<Char,Traits,OFoptional_traits<T>::is_default_constructible::value> {};
     template<typename Char,typename Traits>
-    struct if_not_constructible : if_istream<Char,Traits,sizeof(sfinae<T>(OFnullptr)) == sizeof(no_type)> {};
-
-// implement "construct" when "emplace" is not supported
-// needed for the istream operator
-#ifndef DCMTK_USE_CXX11_STL
-    void construct() { state() = 1; new (content()) T; }
-#endif // C++11
+    struct if_not_constructible : if_istream<Char,Traits,!OFoptional_traits<T>::is_default_constructible::value> {};
 
 public:
     // generic output stream operator overload
@@ -354,11 +527,7 @@ public:
     {
         if( !opt )
         {
-#ifdef DCMTK_USE_CXX11_STL
-            opt.emplace();
-#else // C++11
             opt.construct();
-#endif // NOT C++11
             if( (is >> *opt).fail() )
                 opt = OFnullopt;
             return is;
@@ -375,178 +544,196 @@ public:
     }
 
     // comparison operator overloads, see expression itself for details
-    friend bool operator==( const OFoptional& lhs, OFnullopt_t )
-    {
-        return !lhs;
-    }
-
-    friend bool operator==( OFnullopt_t, const OFoptional& rhs )
+    template<typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator==( OFnullopt_t, const O& rhs )
     {
         return !rhs;
     }
 
-    friend bool operator==( const OFoptional& lhs, const OFoptional& rhs )
-    {
-        return ( !lhs && !rhs ) || ( lhs.state() == rhs.state() && *lhs == *rhs );
-    }
-
-    template<typename X>
-    friend bool operator==( const OFoptional& lhs, const X& rhs )
-    {
-        return lhs.state() && *lhs == rhs;
-    }
-
-    template<typename X>
-    friend bool operator==(  const X& lhs, const OFoptional& rhs )
+    template<typename X,typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator==( const X& lhs, const O& rhs )
     {
         return rhs.state() && lhs == *rhs;
     }
 
-    friend bool operator!=( const OFoptional& lhs, OFnullopt_t )
-    {
-        return lhs.state();
-    }
-
-    friend bool operator!=( OFnullopt_t, const OFoptional& rhs )
+    template<typename O>
+    friend typename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator!=( OFnullopt_t, const O& rhs )
     {
         return rhs.state();
     }
 
-    friend bool operator!=( const OFoptional& lhs, const OFoptional& rhs )
+    template<typename X,typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator!=( const X& lhs, const O& rhs )
     {
-        return lhs.state() != rhs.state() || ( lhs.state() && *lhs != *rhs );
+        return !rhs || lhs != *rhs;
     }
 
-    template<typename X>
-    friend bool operator!=( const OFoptional& lhs, const X& rhs )
-    {
-        return !lhs || *lhs != rhs;
-    }
-
-    template<typename X>
-    friend bool operator!=(  const X& lhs, const OFoptional& rhs )
-    {
-        return !rhs || lhs == *rhs;
-    }
-
-    friend bool operator<( const OFoptional& lhs, OFnullopt_t )
-    {
-        return OFFalse;
-    }
-
-    friend bool operator<( OFnullopt_t, const OFoptional& rhs )
+    template<typename O>
+    friend typename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator<( OFnullopt_t, const O& rhs )
     {
         return rhs.state();
     }
 
-    friend bool operator<( const OFoptional& lhs, const OFoptional& rhs )
-    {
-        return lhs.state() < rhs.state() || ( rhs.state() && *lhs < *rhs );
-    }
-
-    template<typename X>
-    friend bool operator<( const OFoptional& lhs, const X& rhs )
-    {
-        return !lhs || *lhs < rhs;
-    }
-
-    template<typename X>
-    friend bool operator<( const X& lhs, const OFoptional& rhs )
+    template<typename X,typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator<( const X& lhs, const O& rhs )
     {
         return rhs.state() && lhs < *rhs;
     }
 
-    friend bool operator>( const OFoptional& lhs, OFnullopt_t )
-    {
-        return lhs.state();
-    }
-
-    friend bool operator>( OFnullopt_t, const OFoptional& rhs )
+    template<typename O>
+    friend typename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator>( OFnullopt_t, const O& rhs )
     {
         return OFFalse;
     }
 
-    friend bool operator>( const OFoptional& lhs, const OFoptional& rhs )
-    {
-        return lhs.state() > rhs.state() || ( lhs.state() && *lhs > *rhs );
-    }
-
-    template<typename X>
-    friend bool operator>( const OFoptional& lhs, const X& rhs )
-    {
-        return lhs.state() && *lhs > rhs;
-    }
-
-    template<typename X>
-    friend bool operator>( const X& lhs, const OFoptional& rhs )
+    template<typename X,typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator>( const X& lhs, const O& rhs )
     {
         return !rhs || lhs > *rhs;
     }
 
-    friend bool operator<=( const OFoptional& lhs, OFnullopt_t )
-    {
-        return !lhs;
-    }
-
-    friend bool operator<=( OFnullopt_t, const OFoptional& rhs )
+    template<typename O>
+    friend typename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator<=( OFnullopt_t, const O& rhs )
     {
         return OFTrue;
     }
 
-    friend bool operator<=( const OFoptional& lhs, const OFoptional& rhs )
-    {
-        return !lhs || ( rhs.state() && *lhs <= *rhs );
-    }
-
-    template<typename X>
-    friend bool operator<=( const OFoptional& lhs, const X& rhs )
-    {
-        return !lhs || *lhs <= rhs;
-    }
-
-    template<typename X>
-    friend bool operator<=( const X& lhs, const OFoptional& rhs )
+    template<typename X,typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator<=( const X& lhs, const O& rhs )
     {
         return rhs.state() && lhs <= *rhs;
     }
 
-    friend bool operator>=( const OFoptional& lhs, OFnullopt_t )
-    {
-        return OFTrue;
-    }
-
-    friend bool operator>=( OFnullopt_t, const OFoptional& rhs )
+    template<typename O>
+    friend typename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator>=( OFnullopt_t, const O& rhs )
     {
         return !rhs;
     }
 
-    friend bool operator>=( const OFoptional& lhs, const OFoptional& rhs )
-    {
-        return !rhs || ( lhs.state() && *lhs >= *rhs );
-    }
-
-    template<typename X>
-    friend bool operator>=( const OFoptional& lhs, const X& rhs )
-    {
-        return lhs.state() && *lhs >= rhs;
-    }
-
-    template<typename X>
-    friend bool operator>=( const X& lhs, const OFoptional& rhs )
+    template<typename X,typename O>
+    friend OFTypename OFenable_if<OFis_same<O,OFoptional>::value,bool>::type
+    operator>=( const X& lhs, const O& rhs )
     {
         return !rhs || lhs >= *rhs;
     }
 
+    bool operator==( OFnullopt_t )
+    {
+        return !*this;
+    }
+
+    bool operator==( const OFoptional& rhs )
+    {
+        return ( !*this && !rhs ) || ( OFoptional_traits<T>::state() == rhs.state() && **this == *rhs );
+    }
+
+    template<typename X>
+    bool operator==( const X& rhs )
+    {
+        return OFoptional_traits<T>::state() && **this == rhs;
+    }
+
+    bool operator!=( OFnullopt_t )
+    {
+        return OFoptional_traits<T>::state();
+    }
+
+    bool operator!=( const OFoptional& rhs )
+    {
+        return OFoptional_traits<T>::state() != rhs.state() || ( rhs.state() && **this != *rhs );
+    }
+
+    template<typename X>
+    bool operator!=( const X& rhs )
+    {
+        return !*this || **this != rhs;
+    }
+
+    bool operator<( OFnullopt_t )
+    {
+        return OFFalse;
+    }
+
+    bool operator<( const OFoptional& rhs )
+    {
+        return OFoptional_traits<T>::state() < rhs.state() || ( rhs.state() && **this < *rhs );
+    }
+
+    template<typename X>
+    bool operator<( const X& rhs )
+    {
+        return !*this || **this < rhs;
+    }
+
+    bool operator>( OFnullopt_t )
+    {
+        return OFoptional_traits<T>::state();
+    }
+
+    bool operator>( const OFoptional& rhs )
+    {
+        return OFoptional_traits<T>::state() > rhs.state() || ( OFoptional_traits<T>::state() && **this > *rhs );
+    }
+
+    template<typename X>
+    bool operator>( const X& rhs )
+    {
+        return OFoptional_traits<T>::state() && **this > rhs;
+    }
+
+    bool operator<=( OFnullopt_t )
+    {
+        return !*this;
+    }
+
+    bool operator<=( const OFoptional& rhs )
+    {
+        return !*this || ( rhs.state() && **this <= *rhs );
+    }
+
+    template<typename X>
+    bool operator<=( const X& rhs )
+    {
+        return !*this || **this <= rhs;
+    }
+
+    bool operator>=( OFnullopt_t )
+    {
+        return OFTrue;
+    }
+
+    bool operator>=( const OFoptional& rhs )
+    {
+        return !rhs || ( OFoptional_traits<T>::state() && **this >= *rhs );
+    }
+
+    template<typename X>
+    bool operator>=( const X& rhs )
+    {
+        return OFoptional_traits<T>::state() && **this >= rhs;
+    }
+
     // Default construct an OFoptional object in the disengaged state.
     OFconstexpr OFoptional()
-    : m_Content()
+    : OFoptional_traits<T>()
     {
 
     }
 
     // Explicitly construct a disengaged OFoptional object.
     OFconstexpr OFoptional( OFnullopt_t )
-    : m_Content()
+    : OFoptional_traits<T>()
     {
 
     }
@@ -561,44 +748,39 @@ public:
 
     }
 #else // C++11
-    : m_Content()
+    : OFoptional_traits<T>()
     {
-        state() = rhs.state();
-        if( state() )
-            new (content()) T( *rhs );
+        if( rhs.state() )
+            OFoptional_traits<T>::construct( *rhs );
     }
 #endif // NOT C++11
 
     // Copy the engaged state from rhs and its contents if rhs is engaged.
     OFoptional( const OFoptional& rhs )
-    : m_Content()
+    : OFoptional_traits<T>()
     {
-        state() = rhs.state();
-        if( state() )
-            new (content()) T( *rhs );
+        if( rhs.state() )
+            OFoptional_traits<T>::construct( *rhs );
     }
 
 #ifdef DCMTK_USE_CXX11_STL
     // Move constructor, kills rhs if it was engaged before.
     OFoptional( OFoptional&& rhs )
-    : m_Content{}
+    : OFoptional_traits<T>()
     {
-        state() = rhs.state();
-        if( state() )
+        if( rhs.state() )
         {
-            new (content()) T( std::move( *rhs ) );
-            rhs.state() = 0;
-            rhs->~T();
+            OFoptional_traits<T>::construct( std::move( *rhs ) );
+            rhs.destroy();
         }
     }
 
     // Variadic constructor that emplaces the content
     template<typename... Args>
     OFoptional( Args&&... args )
-    : m_Content{}
+    : OFoptional_traits<T>()
     {
-        state() = 1;
-        new (content()) T( std::forward<Args>( args )... );
+        OFoptional_traits<T>::construct( std::forward<Args>( args )... );
     }
 
     // Move assignment
@@ -609,25 +791,22 @@ public:
         {
             // if both objects are engaged, move content
             // and kill rhs
-            if( state() == rhs.state() )
+            if( OFoptional_traits<T>::state() == rhs.state() )
             {
-                if( state() )
+                if( OFoptional_traits<T>::state() )
                 {
                     (**this) = std::move( *rhs );
-                    rhs.state() = 0;
-                    rhs->~T();
+                    rhs.destroy();
                 }
             }
-            else if( state() ) // suicide if engaged and rhs isn't
+            else if( OFoptional_traits<T>::state() ) // suicide if engaged and rhs isn't
             {
-                state() = 0;
-                (*this)->~T();
+                OFoptional_traits<T>::destroy();
             }
             else // if rhs is engaged and we aren't, swap states, move contents and kill rhs.
             {
-                OFswap( state(), rhs.state() );
-                new (content()) T( std::move( *rhs ) );
-                rhs->~T();
+                OFoptional_traits<T>::construct( std::move( *rhs ) );
+                rhs.destroy();
             }
         }
         return *this;
@@ -638,34 +817,27 @@ public:
     OFoptional& emplace( Args&&... args )
     {
         // emplace construct if we are disengaged
-        if( !state() )
-        {
-            state() = 1;
-            new (content()) T( std::forward<Args>( args )... );
-        }
-        else (**this) = T( std::forward<Args>( args )... ); // only emplace new content
+        if( !OFoptional_traits<T>::state() )
+            OFoptional_traits<T>::construct( std::forward<Args>( args )... );
+        else
+            (**this) = T( std::forward<Args>( args )... ); // only emplace new content
         return *this;
     }
 #else // C++11
     // Construct an engaged OFoptional object containing a copy of x.
     template<typename X>
     OFoptional( const X& x )
-    : m_Content()
+    : OFoptional_traits<T>()
     {
-        state() = 1;
-        new (content()) T( x );
+        OFoptional_traits<T>::construct( x );
     }
 #endif // NOT C++11
 
     // Destroy the contained object if engaged, otherwise do nothing.
     ~OFoptional()
     {
-        if( state() )
-#ifndef _MSC_VER
-            (*this)->~T();
-#else // Workaround bug in Microsoft compilers
-            operator->()->~T();
-#endif
+        if( OFoptional_traits<T>::state() )
+            OFoptional_traits<T>::destroy();
     }
 
     // False friend of the assignment operator to prevent wrong behavior
@@ -682,23 +854,17 @@ public:
         if( &rhs != this )
         {
             // if both objects are engaged, copy content
-            if( state() == rhs.state() )
+            if( OFoptional_traits<T>::state() == rhs.state() )
             {
-                if( state() ) (**this) = *rhs;
+                if( OFoptional_traits<T>::state() ) (**this) = *rhs;
             }
-            else if( state() ) // suicide if engaged and rhs isn't
+            else if( OFoptional_traits<T>::state() ) // suicide if engaged and rhs isn't
             {
-                state() = 0;
-#ifndef _MSC_VER
-                (*this)->~T();
-#else // Workaround bug in Microsoft compilers
-                operator->()->~T();
-#endif
+                OFoptional_traits<T>::destroy();
             }
             else // if rhs is engaged and we aren't, copy-construct from rhs.
             {
-                state() = 1;
-                new (content()) T( *rhs );
+                OFoptional_traits<T>::construct( *rhs );
             }
         }
         return *this;
@@ -712,66 +878,48 @@ public:
 #endif // C++11
     operator OFBool() const
     {
-        return state() != 0;
+        return OFoptional_traits<T>::state();
     }
 
     OFBool operator!() const
     {
-        return !state();
+        return !OFoptional_traits<T>::state();
     }
 
     T& operator*() const
     {
-        return *static_cast<T*>( content() );
+        return *OFstatic_cast( T*, OFoptional_traits<T>::content() );
     }
 
     T* operator->() const
     {
-        return static_cast<T*>( content() );
+        return OFstatic_cast( T*, OFoptional_traits<T>::content() );
     }
 
     // Swap the contents with another OFoptional object.
     void swap( OFoptional& rhs )
     {
         // if both objects are engaged, the contents are swapped.
-        if( state() == rhs.state() )
+        if( OFoptional_traits<T>::state() == rhs.state() )
         {
-            if( state() ) OFswap( **this, *rhs );
+            if( OFoptional_traits<T>::state() ) OFswap( **this, *rhs );
         }
         else
         {
             // if we are engaged and rhs isn't, move assign
             // our contents to rhs.
-            if( state() )
+            if( OFoptional_traits<T>::state() )
             {
-                new (rhs.content()) T( OFmove( **this ) );
-#ifndef _MSC_VER
-                (*this)->~T();
-#else // Workaround bug in Microsoft compilers
-                operator->()->~T();
-#endif
+                rhs.construct( OFmove( **this ) );
+                OFoptional_traits<T>::destroy();
             }
             else // else move assign rhs' contents to us
             {
-                new (content()) T( OFmove( *rhs ) );
-#ifndef _MSC_VER
-                rhs->~T();
-#else // Workaround bug in Microsoft compilers
-                rhs.operator->()->~T();
-#endif
+                OFoptional_traits<T>::construct( OFmove( *rhs ) );
+                rhs.destroy();
             }
-            // finally, swap the states
-            OFswap( state(), rhs.state() );
         }
     }
-
-private:
-    // State and content are stored in the same data-array to
-    // optimize alignment and so on. Mutable, since the content
-    // itself can be modified even if it cant be (re-)assigned.
-    void* content() const { return m_Content; }
-    Uint8& state() const { return m_Content[sizeof(T)]; }
-    mutable Uint8 m_Content[sizeof(T)+1];
 #endif // NOT DOXYGEN
 };
 
