@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2001-2014, OFFIS e.V.
+ *  Copyright (C) 2001-2015, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -96,6 +96,7 @@
 #include "dcmtk/ofstd/ofcond.h"
 #include "dcmtk/ofstd/offile.h"
 #include "dcmtk/ofstd/ofstream.h"
+#include "dcmtk/ofstd/oftuple.h"
 
 #define INCLUDE_CMATH
 #define INCLUDE_CFLOAT
@@ -196,6 +197,9 @@ extern "C"
 #endif
 #endif
 
+#if !defined(HAVE_ISINF) && defined(HAVE_PROTOTYPE_ISINF)
+#   define HAVE_ISINF 1
+#endif
 
 // some systems don't properly define isinf()
 #ifdef HAVE_ISINF
@@ -1984,6 +1988,41 @@ double OFStandard::atof(const char *s, OFBool *success)
 
 #endif /* DISABLE_OFSTD_ATOF */
 
+OFBool OFStandard::isnan( float f )
+{
+#ifdef HAVE_WINDOWS_H
+  return _isnan(f);
+#else
+  return ::isnan(f);
+#endif
+}
+
+OFBool OFStandard::isnan( double d )
+{
+#ifdef HAVE_WINDOWS_H
+  return _isnan(d);
+#else
+  return ::isnan(d);
+#endif
+}
+
+OFBool OFStandard::isinf( float f )
+{
+#ifdef HAVE_ISINF
+  return ::isinf( f );
+#else
+  return my_isinf( f );
+#endif
+}
+
+OFBool OFStandard::isinf( double d )
+{
+#ifdef HAVE_ISINF
+  return ::isinf( d );
+#else
+  return my_isinf( d );
+#endif
+}
 
 /* 11-bit exponent (VAX G floating point) is 308 decimal digits */
 #define FTOA_MAXEXP          308
@@ -2024,22 +2063,14 @@ void OFStandard::ftoa(
   unsigned char fmtch = 'G';
 
   // check if val is NAN
-#ifdef HAVE_WINDOWS_H
-  if (_isnan(val))
-#else
   if (isnan(val))
-#endif
   {
     OFStandard::strlcpy(dst, "nan", siz);
     return;
   }
 
   // check if val is infinity
-#ifdef HAVE_ISINF
   if (isinf(val))
-#else
-  if (my_isinf(val))
-#endif
   {
     if (val < 0)
         OFStandard::strlcpy(dst, "-inf", siz);
@@ -2835,7 +2866,9 @@ OFStandard::OFPasswd::OFPasswd( passwd* const p )
         pw_passwd = p->pw_passwd;
         pw_uid    = p->pw_uid;
         pw_gid    = p->pw_gid;
+#ifdef HAVE_PASSWD_GECOS
         pw_gecos  = p->pw_gecos;
+#endif
         pw_dir    = p->pw_dir;
         pw_shell  = p->pw_shell;
     }
@@ -2869,4 +2902,8 @@ OFCondition OFStandard::dropPrivileges()
 #ifndef DCMTK_USE_CXX11_STL
 DCMTK_OFSTD_EXPORT OFnullptr_t OFnullptr;
 DCMTK_OFSTD_EXPORT OFnullopt_t OFnullopt;
+static const OFignore_t OFignore_value;
+DCMTK_OFSTD_EXPORT const OFignore_t& OFignore( OFignore_value );
+OFtuple<> OFmake_tuple() { return OFtuple<>(); }
+OFtuple<> OFtie() { return OFtuple<>(); }
 #endif
